/* devicesGroup.c generated by valac 0.56.19, the Vala compiler
 * generated from devicesGroup.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <libxml/xmlwriter.h>
#include <libxml/tree.h>
#include <glib.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_ACTION_GROUP (gnome_pie_action_group_get_type ())
#define GNOME_PIE_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup))
#define GNOME_PIE_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))
#define GNOME_PIE_IS_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_IS_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_ACTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))

typedef struct _GnomePieActionGroup GnomePieActionGroup;
typedef struct _GnomePieActionGroupClass GnomePieActionGroupClass;
typedef struct _GnomePieActionGroupPrivate GnomePieActionGroupPrivate;

#define GNOME_PIE_TYPE_DEVICES_GROUP (gnome_pie_devices_group_get_type ())
#define GNOME_PIE_DEVICES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroup))
#define GNOME_PIE_DEVICES_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroupClass))
#define GNOME_PIE_IS_DEVICES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_DEVICES_GROUP))
#define GNOME_PIE_IS_DEVICES_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_DEVICES_GROUP))
#define GNOME_PIE_DEVICES_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroupClass))

typedef struct _GnomePieDevicesGroup GnomePieDevicesGroup;
typedef struct _GnomePieDevicesGroupClass GnomePieDevicesGroupClass;
typedef struct _GnomePieDevicesGroupPrivate GnomePieDevicesGroupPrivate;
enum  {
	GNOME_PIE_DEVICES_GROUP_0_PROPERTY,
	GNOME_PIE_DEVICES_GROUP_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_devices_group_properties[GNOME_PIE_DEVICES_GROUP_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION (gnome_pie_group_registry_typedescription_get_type ())
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescription))
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescriptionClass))
#define GNOME_PIE_GROUP_REGISTRY_IS_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_GROUP_REGISTRY_IS_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescriptionClass))

typedef struct _GnomePieGroupRegistryTypeDescription GnomePieGroupRegistryTypeDescription;
typedef struct _GnomePieGroupRegistryTypeDescriptionClass GnomePieGroupRegistryTypeDescriptionClass;

#define GNOME_PIE_TYPE_ACTION (gnome_pie_action_get_type ())
#define GNOME_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION, GnomePieAction))
#define GNOME_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))
#define GNOME_PIE_IS_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_IS_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))

typedef struct _GnomePieAction GnomePieAction;
typedef struct _GnomePieActionClass GnomePieActionClass;

#define GNOME_PIE_TYPE_URI_ACTION (gnome_pie_uri_action_get_type ())
#define GNOME_PIE_URI_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriAction))
#define GNOME_PIE_URI_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriActionClass))
#define GNOME_PIE_IS_URI_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_URI_ACTION))
#define GNOME_PIE_IS_URI_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_URI_ACTION))
#define GNOME_PIE_URI_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriActionClass))

typedef struct _GnomePieUriAction GnomePieUriAction;
typedef struct _GnomePieUriActionClass GnomePieUriActionClass;
#define _g_free0(var) (var = (g_free (var), NULL))

struct _GnomePieActionGroup {
	GObject parent_instance;
	GnomePieActionGroupPrivate * priv;
};

struct _GnomePieActionGroupClass {
	GObjectClass parent_class;
	void (*on_remove) (GnomePieActionGroup* self);
	void (*on_save) (GnomePieActionGroup* self, xmlTextWriter* writer);
	void (*on_load) (GnomePieActionGroup* self, xmlNode* data);
};

struct _GnomePieDevicesGroup {
	GnomePieActionGroup parent_instance;
	GnomePieDevicesGroupPrivate * priv;
};

struct _GnomePieDevicesGroupClass {
	GnomePieActionGroupClass parent_class;
};

struct _GnomePieDevicesGroupPrivate {
	gboolean changing;
	gboolean changed_again;
	GVolumeMonitor* monitor;
};

static gint GnomePieDevicesGroup_private_offset;
static gpointer gnome_pie_devices_group_parent_class = NULL;

VALA_EXTERN GType gnome_pie_action_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionGroup, g_object_unref)
VALA_EXTERN GType gnome_pie_devices_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieDevicesGroup, g_object_unref)
VALA_EXTERN gpointer gnome_pie_group_registry_typedescription_ref (gpointer instance);
VALA_EXTERN void gnome_pie_group_registry_typedescription_unref (gpointer instance);
VALA_EXTERN GParamSpec* gnome_pie_group_registry_param_spec_typedescription (const gchar* name,
                                                                 const gchar* nick,
                                                                 const gchar* blurb,
                                                                 GType object_type,
                                                                 GParamFlags flags);
VALA_EXTERN void gnome_pie_group_registry_value_set_typedescription (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN void gnome_pie_group_registry_value_take_typedescription (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN gpointer gnome_pie_group_registry_value_get_typedescription (const GValue* value);
VALA_EXTERN GType gnome_pie_group_registry_typedescription_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieGroupRegistryTypeDescription, gnome_pie_group_registry_typedescription_unref)
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_devices_group_register (void);
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_group_registry_typedescription_new (void);
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_group_registry_typedescription_construct (GType object_type);
VALA_EXTERN void gnome_pie_group_registry_typedescription_set_name (GnomePieGroupRegistryTypeDescription* self,
                                                        const gchar* value);
VALA_EXTERN void gnome_pie_group_registry_typedescription_set_icon (GnomePieGroupRegistryTypeDescription* self,
                                                        const gchar* value);
VALA_EXTERN void gnome_pie_group_registry_typedescription_set_description (GnomePieGroupRegistryTypeDescription* self,
                                                               const gchar* value);
VALA_EXTERN void gnome_pie_group_registry_typedescription_set_id (GnomePieGroupRegistryTypeDescription* self,
                                                      const gchar* value);
VALA_EXTERN GnomePieDevicesGroup* gnome_pie_devices_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieDevicesGroup* gnome_pie_devices_group_construct (GType object_type,
                                                         const gchar* parent_id);
static void gnome_pie_devices_group_load (GnomePieDevicesGroup* self);
VALA_EXTERN GType gnome_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAction, g_object_unref)
VALA_EXTERN void gnome_pie_action_group_add_action (GnomePieActionGroup* self,
                                        GnomePieAction* new_action);
VALA_EXTERN GnomePieUriAction* gnome_pie_uri_action_new (const gchar* name,
                                             const gchar* icon,
                                             const gchar* command,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePieUriAction* gnome_pie_uri_action_construct (GType object_type,
                                                   const gchar* name,
                                                   const gchar* icon,
                                                   const gchar* command,
                                                   gboolean is_quickaction);
VALA_EXTERN GType gnome_pie_uri_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieUriAction, g_object_unref)
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
static void gnome_pie_devices_group_reload (GnomePieDevicesGroup* self);
static gboolean ___lambda22_ (GnomePieDevicesGroup* self);
VALA_EXTERN void gnome_pie_action_group_delete_all (GnomePieActionGroup* self);
static gboolean ____lambda22__gsource_func (gpointer self);
static GObject * gnome_pie_devices_group_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties);
static void _gnome_pie_devices_group_reload_g_volume_monitor_mount_added (GVolumeMonitor* _sender,
                                                                   GMount* mount,
                                                                   gpointer self);
static void _gnome_pie_devices_group_reload_g_volume_monitor_mount_removed (GVolumeMonitor* _sender,
                                                                     GMount* mount,
                                                                     gpointer self);
static void gnome_pie_devices_group_finalize (GObject * obj);
static GType gnome_pie_devices_group_get_type_once (void);

static inline gpointer
gnome_pie_devices_group_get_instance_private (GnomePieDevicesGroup* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePieDevicesGroup_private_offset);
}

GnomePieGroupRegistryTypeDescription*
gnome_pie_devices_group_register (void)
{
	GnomePieGroupRegistryTypeDescription* description = NULL;
	GnomePieGroupRegistryTypeDescription* _tmp0_;
	GnomePieGroupRegistryTypeDescription* result;
	_tmp0_ = gnome_pie_group_registry_typedescription_new ();
	description = _tmp0_;
	gnome_pie_group_registry_typedescription_set_name (description, _ ("Group: Devices"));
	gnome_pie_group_registry_typedescription_set_icon (description, "drive-harddisk");
	gnome_pie_group_registry_typedescription_set_description (description, _ ("Shows a Slice for each plugged in devices, like USB-Sticks."));
	gnome_pie_group_registry_typedescription_set_id (description, "devices");
	result = description;
	return result;
}

GnomePieDevicesGroup*
gnome_pie_devices_group_construct (GType object_type,
                                   const gchar* parent_id)
{
	GnomePieDevicesGroup * self = NULL;
	g_return_val_if_fail (parent_id != NULL, NULL);
	self = (GnomePieDevicesGroup*) g_object_new (object_type, "parent-id", parent_id, NULL);
	return self;
}

GnomePieDevicesGroup*
gnome_pie_devices_group_new (const gchar* parent_id)
{
	return gnome_pie_devices_group_construct (GNOME_PIE_TYPE_DEVICES_GROUP, parent_id);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_g_object_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}

static inline void
_g_list_free__g_object_unref0_ (GList* self)
{
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
}

static void
gnome_pie_devices_group_load (GnomePieDevicesGroup* self)
{
	GnomePieUriAction* _tmp0_;
	GnomePieUriAction* _tmp1_;
	GVolumeMonitor* _tmp2_;
	GList* _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = gnome_pie_uri_action_new (_ ("Root"), "drive-harddisk", "file:///", FALSE);
	_tmp1_ = _tmp0_;
	gnome_pie_action_group_add_action ((GnomePieActionGroup*) self, (GnomePieAction*) _tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = self->priv->monitor;
	_tmp3_ = g_volume_monitor_get_mounts (_tmp2_);
	{
		GList* mount_collection = NULL;
		GList* mount_it = NULL;
		mount_collection = _tmp3_;
		for (mount_it = mount_collection; mount_it != NULL; mount_it = mount_it->next) {
			GMount* _tmp4_;
			GMount* mount = NULL;
			_tmp4_ = _g_object_ref0 ((GMount*) mount_it->data);
			mount = _tmp4_;
			{
				GIcon* icon = NULL;
				GMount* _tmp5_;
				GIcon* _tmp6_;
				GMount* _tmp7_;
				gchar* _tmp8_;
				gchar* _tmp9_;
				GIcon* _tmp10_;
				gchar* _tmp11_;
				gchar* _tmp12_;
				GMount* _tmp13_;
				GFile* _tmp14_;
				GFile* _tmp15_;
				gchar* _tmp16_;
				gchar* _tmp17_;
				GnomePieUriAction* _tmp18_;
				GnomePieUriAction* _tmp19_;
				_tmp5_ = mount;
				_tmp6_ = g_mount_get_icon (_tmp5_);
				icon = _tmp6_;
				_tmp7_ = mount;
				_tmp8_ = g_mount_get_name (_tmp7_);
				_tmp9_ = _tmp8_;
				_tmp10_ = icon;
				_tmp11_ = g_icon_to_string (_tmp10_);
				_tmp12_ = _tmp11_;
				_tmp13_ = mount;
				_tmp14_ = g_mount_get_root (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp16_ = g_file_get_uri (_tmp15_);
				_tmp17_ = _tmp16_;
				_tmp18_ = gnome_pie_uri_action_new (_tmp9_, _tmp12_, _tmp17_, FALSE);
				_tmp19_ = _tmp18_;
				gnome_pie_action_group_add_action ((GnomePieActionGroup*) self, (GnomePieAction*) _tmp19_);
				_g_object_unref0 (_tmp19_);
				_g_free0 (_tmp17_);
				_g_object_unref0 (_tmp15_);
				_g_free0 (_tmp12_);
				_g_free0 (_tmp9_);
				_g_object_unref0 (icon);
				_g_object_unref0 (mount);
			}
		}
		(mount_collection == NULL) ? NULL : (mount_collection = (_g_list_free__g_object_unref0_ (mount_collection), NULL));
	}
}

static gboolean
___lambda22_ (GnomePieDevicesGroup* self)
{
	gboolean result;
	if (self->priv->changed_again) {
		self->priv->changed_again = FALSE;
		result = TRUE;
		return result;
	}
	g_message ("devicesGroup.vala:118: Devices changed...");
	gnome_pie_action_group_delete_all ((GnomePieActionGroup*) self);
	gnome_pie_devices_group_load (self);
	self->priv->changing = FALSE;
	result = FALSE;
	return result;
}

static gboolean
____lambda22__gsource_func (gpointer self)
{
	gboolean result;
	result = ___lambda22_ ((GnomePieDevicesGroup*) self);
	return result;
}

static void
gnome_pie_devices_group_reload (GnomePieDevicesGroup* self)
{
	g_return_if_fail (self != NULL);
	if (!self->priv->changing) {
		self->priv->changing = TRUE;
		g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) 200, ____lambda22__gsource_func, g_object_ref (self), g_object_unref);
	} else {
		self->priv->changed_again = TRUE;
	}
}

static void
_gnome_pie_devices_group_reload_g_volume_monitor_mount_added (GVolumeMonitor* _sender,
                                                              GMount* mount,
                                                              gpointer self)
{
	gnome_pie_devices_group_reload ((GnomePieDevicesGroup*) self);
}

static void
_gnome_pie_devices_group_reload_g_volume_monitor_mount_removed (GVolumeMonitor* _sender,
                                                                GMount* mount,
                                                                gpointer self)
{
	gnome_pie_devices_group_reload ((GnomePieDevicesGroup*) self);
}

static GObject *
gnome_pie_devices_group_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GnomePieDevicesGroup * self;
	GVolumeMonitor* _tmp0_;
	GVolumeMonitor* _tmp1_;
	GVolumeMonitor* _tmp2_;
	parent_class = G_OBJECT_CLASS (gnome_pie_devices_group_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroup);
	_tmp0_ = g_volume_monitor_get ();
	_g_object_unref0 (self->priv->monitor);
	self->priv->monitor = _tmp0_;
	gnome_pie_devices_group_load (self);
	_tmp1_ = self->priv->monitor;
	g_signal_connect_object (_tmp1_, "mount-added", (GCallback) _gnome_pie_devices_group_reload_g_volume_monitor_mount_added, self, 0);
	_tmp2_ = self->priv->monitor;
	g_signal_connect_object (_tmp2_, "mount-removed", (GCallback) _gnome_pie_devices_group_reload_g_volume_monitor_mount_removed, self, 0);
	return obj;
}

static void
gnome_pie_devices_group_class_init (GnomePieDevicesGroupClass * klass,
                                    gpointer klass_data)
{
	gnome_pie_devices_group_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GnomePieDevicesGroup_private_offset);
	G_OBJECT_CLASS (klass)->constructor = gnome_pie_devices_group_constructor;
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_devices_group_finalize;
}

static void
gnome_pie_devices_group_instance_init (GnomePieDevicesGroup * self,
                                       gpointer klass)
{
	self->priv = gnome_pie_devices_group_get_instance_private (self);
	self->priv->changing = FALSE;
	self->priv->changed_again = FALSE;
}

static void
gnome_pie_devices_group_finalize (GObject * obj)
{
	GnomePieDevicesGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroup);
	_g_object_unref0 (self->priv->monitor);
	G_OBJECT_CLASS (gnome_pie_devices_group_parent_class)->finalize (obj);
}

static GType
gnome_pie_devices_group_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieDevicesGroupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_devices_group_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieDevicesGroup), 0, (GInstanceInitFunc) gnome_pie_devices_group_instance_init, NULL };
	GType gnome_pie_devices_group_type_id;
	gnome_pie_devices_group_type_id = g_type_register_static (GNOME_PIE_TYPE_ACTION_GROUP, "GnomePieDevicesGroup", &g_define_type_info, 0);
	GnomePieDevicesGroup_private_offset = g_type_add_instance_private (gnome_pie_devices_group_type_id, sizeof (GnomePieDevicesGroupPrivate));
	return gnome_pie_devices_group_type_id;
}

GType
gnome_pie_devices_group_get_type (void)
{
	static volatile gsize gnome_pie_devices_group_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_devices_group_type_id__once)) {
		GType gnome_pie_devices_group_type_id;
		gnome_pie_devices_group_type_id = gnome_pie_devices_group_get_type_once ();
		g_once_init_leave (&gnome_pie_devices_group_type_id__once, gnome_pie_devices_group_type_id);
	}
	return gnome_pie_devices_group_type_id__once;
}

