/* sliceLayer.c generated by valac 0.56.19, the Vala compiler
 * generated from sliceLayer.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_SLICE_LAYER (gnome_pie_slice_layer_get_type ())
#define GNOME_PIE_SLICE_LAYER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_SLICE_LAYER, GnomePieSliceLayer))
#define GNOME_PIE_SLICE_LAYER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_SLICE_LAYER, GnomePieSliceLayerClass))
#define GNOME_PIE_IS_SLICE_LAYER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_SLICE_LAYER))
#define GNOME_PIE_IS_SLICE_LAYER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_SLICE_LAYER))
#define GNOME_PIE_SLICE_LAYER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_SLICE_LAYER, GnomePieSliceLayerClass))

typedef struct _GnomePieSliceLayer GnomePieSliceLayer;
typedef struct _GnomePieSliceLayerClass GnomePieSliceLayerClass;
typedef struct _GnomePieSliceLayerPrivate GnomePieSliceLayerPrivate;
typedef enum  {
	GNOME_PIE_SLICE_LAYER_TYPE_FILE,
	GNOME_PIE_SLICE_LAYER_TYPE_ICON,
	GNOME_PIE_SLICE_LAYER_TYPE_CAPTION
} GnomePieSliceLayerType;

#define GNOME_PIE_SLICE_LAYER_TYPE_TYPE (gnome_pie_slice_layer_type_get_type ())
typedef enum  {
	GNOME_PIE_SLICE_LAYER_VISIBILITY_ANY,
	GNOME_PIE_SLICE_LAYER_VISIBILITY_WITH_CAPTION,
	GNOME_PIE_SLICE_LAYER_VISIBILITY_WITHOUT_CAPTION
} GnomePieSliceLayerVisibility;

#define GNOME_PIE_SLICE_LAYER_TYPE_VISIBILITY (gnome_pie_slice_layer_visibility_get_type ())

#define GNOME_PIE_TYPE_IMAGE (gnome_pie_image_get_type ())
#define GNOME_PIE_IMAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_IMAGE, GnomePieImage))
#define GNOME_PIE_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_IMAGE, GnomePieImageClass))
#define GNOME_PIE_IS_IMAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_IMAGE))
#define GNOME_PIE_IS_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_IMAGE))
#define GNOME_PIE_IMAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_IMAGE, GnomePieImageClass))

typedef struct _GnomePieImage GnomePieImage;
typedef struct _GnomePieImageClass GnomePieImageClass;

#define GNOME_PIE_TYPE_COLOR (gnome_pie_color_get_type ())
#define GNOME_PIE_COLOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_COLOR, GnomePieColor))
#define GNOME_PIE_COLOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_COLOR, GnomePieColorClass))
#define GNOME_PIE_IS_COLOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_COLOR))
#define GNOME_PIE_IS_COLOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_COLOR))
#define GNOME_PIE_COLOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_COLOR, GnomePieColorClass))

typedef struct _GnomePieColor GnomePieColor;
typedef struct _GnomePieColorClass GnomePieColorClass;
enum  {
	GNOME_PIE_SLICE_LAYER_0_PROPERTY,
	GNOME_PIE_SLICE_LAYER_LAYER_TYPE_PROPERTY,
	GNOME_PIE_SLICE_LAYER_VISIBILITY_PROPERTY,
	GNOME_PIE_SLICE_LAYER_IMAGE_PROPERTY,
	GNOME_PIE_SLICE_LAYER_ICON_FILE_PROPERTY,
	GNOME_PIE_SLICE_LAYER_COLORIZE_PROPERTY,
	GNOME_PIE_SLICE_LAYER_ICON_SIZE_PROPERTY,
	GNOME_PIE_SLICE_LAYER_FONT_PROPERTY,
	GNOME_PIE_SLICE_LAYER_WIDTH_PROPERTY,
	GNOME_PIE_SLICE_LAYER_HEIGHT_PROPERTY,
	GNOME_PIE_SLICE_LAYER_X_PROPERTY,
	GNOME_PIE_SLICE_LAYER_Y_PROPERTY,
	GNOME_PIE_SLICE_LAYER_COLOR_PROPERTY,
	GNOME_PIE_SLICE_LAYER_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

struct _GnomePieSliceLayer {
	GObject parent_instance;
	GnomePieSliceLayerPrivate * priv;
};

struct _GnomePieSliceLayerClass {
	GObjectClass parent_class;
};

struct _GnomePieSliceLayerPrivate {
	GnomePieSliceLayerType _layer_type;
	GnomePieSliceLayerVisibility _visibility;
	GnomePieImage* _image;
	gchar* _icon_file;
	gboolean _colorize;
	gint _icon_size;
	gchar* _font;
	gint _width;
	gint _height;
	gint _x;
	gint _y;
	GnomePieColor* _color;
};

static gint GnomePieSliceLayer_private_offset;
static gpointer gnome_pie_slice_layer_parent_class = NULL;

VALA_EXTERN GType gnome_pie_slice_layer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieSliceLayer, g_object_unref)
VALA_EXTERN GType gnome_pie_slice_layer_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType gnome_pie_slice_layer_visibility_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType gnome_pie_image_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieImage, g_object_unref)
VALA_EXTERN GType gnome_pie_color_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieColor, g_object_unref)
VALA_EXTERN GnomePieColor* gnome_pie_color_new (void);
VALA_EXTERN GnomePieColor* gnome_pie_color_construct (GType object_type);
VALA_EXTERN GnomePieSliceLayer* gnome_pie_slice_layer_new_file (const gchar* icon_file,
                                                    gint icon_size,
                                                    gint x,
                                                    gint y,
                                                    gboolean colorize,
                                                    GnomePieSliceLayerVisibility visibility);
VALA_EXTERN GnomePieSliceLayer* gnome_pie_slice_layer_construct_file (GType object_type,
                                                          const gchar* icon_file,
                                                          gint icon_size,
                                                          gint x,
                                                          gint y,
                                                          gboolean colorize,
                                                          GnomePieSliceLayerVisibility visibility);
static void gnome_pie_slice_layer_set_layer_type (GnomePieSliceLayer* self,
                                           GnomePieSliceLayerType value);
static void gnome_pie_slice_layer_set_icon_file (GnomePieSliceLayer* self,
                                          const gchar* value);
static void gnome_pie_slice_layer_set_colorize (GnomePieSliceLayer* self,
                                         gboolean value);
static void gnome_pie_slice_layer_set_icon_size (GnomePieSliceLayer* self,
                                          gint value);
static void gnome_pie_slice_layer_set_x (GnomePieSliceLayer* self,
                                  gint value);
static void gnome_pie_slice_layer_set_y (GnomePieSliceLayer* self,
                                  gint value);
static void gnome_pie_slice_layer_set_visibility (GnomePieSliceLayer* self,
                                           GnomePieSliceLayerVisibility value);
VALA_EXTERN GnomePieSliceLayer* gnome_pie_slice_layer_new_icon (const gchar* icon_file,
                                                    gint icon_size,
                                                    gint x,
                                                    gint y,
                                                    gboolean colorize,
                                                    GnomePieSliceLayerVisibility visibility);
VALA_EXTERN GnomePieSliceLayer* gnome_pie_slice_layer_construct_icon (GType object_type,
                                                          const gchar* icon_file,
                                                          gint icon_size,
                                                          gint x,
                                                          gint y,
                                                          gboolean colorize,
                                                          GnomePieSliceLayerVisibility visibility);
VALA_EXTERN GnomePieSliceLayer* gnome_pie_slice_layer_new_caption (const gchar* font,
                                                       gint width,
                                                       gint height,
                                                       gint x,
                                                       gint y,
                                                       GnomePieColor* color,
                                                       gboolean colorize,
                                                       GnomePieSliceLayerVisibility visibility);
VALA_EXTERN GnomePieSliceLayer* gnome_pie_slice_layer_construct_caption (GType object_type,
                                                             const gchar* font,
                                                             gint width,
                                                             gint height,
                                                             gint x,
                                                             gint y,
                                                             GnomePieColor* color,
                                                             gboolean colorize,
                                                             GnomePieSliceLayerVisibility visibility);
static void gnome_pie_slice_layer_set_font (GnomePieSliceLayer* self,
                                     const gchar* value);
static void gnome_pie_slice_layer_set_width (GnomePieSliceLayer* self,
                                      gint value);
static void gnome_pie_slice_layer_set_height (GnomePieSliceLayer* self,
                                       gint value);
static void gnome_pie_slice_layer_set_color (GnomePieSliceLayer* self,
                                      GnomePieColor* value);
VALA_EXTERN void gnome_pie_slice_layer_load_image (GnomePieSliceLayer* self);
VALA_EXTERN void gnome_pie_slice_layer_set_image (GnomePieSliceLayer* self,
                                      GnomePieImage* value);
VALA_EXTERN const gchar* gnome_pie_slice_layer_get_icon_file (GnomePieSliceLayer* self);
VALA_EXTERN GnomePieSliceLayerType gnome_pie_slice_layer_get_layer_type (GnomePieSliceLayer* self);
VALA_EXTERN gint gnome_pie_slice_layer_get_icon_size (GnomePieSliceLayer* self);
VALA_EXTERN GnomePieColor* gnome_pie_color_new_from_rgb (gfloat red,
                                             gfloat green,
                                             gfloat blue);
VALA_EXTERN GnomePieColor* gnome_pie_color_construct_from_rgb (GType object_type,
                                                   gfloat red,
                                                   gfloat green,
                                                   gfloat blue);
VALA_EXTERN GnomePieImage* gnome_pie_image_new_empty (gint width,
                                          gint height,
                                          GnomePieColor* color);
VALA_EXTERN GnomePieImage* gnome_pie_image_construct_empty (GType object_type,
                                                gint width,
                                                gint height,
                                                GnomePieColor* color);
VALA_EXTERN GnomePieImage* gnome_pie_image_new_from_file_at_size (const gchar* filename,
                                                      gint width,
                                                      gint height);
VALA_EXTERN GnomePieImage* gnome_pie_image_construct_from_file_at_size (GType object_type,
                                                            const gchar* filename,
                                                            gint width,
                                                            gint height);
VALA_EXTERN GnomePieSliceLayer* gnome_pie_slice_layer_new (void);
VALA_EXTERN GnomePieSliceLayer* gnome_pie_slice_layer_construct (GType object_type);
VALA_EXTERN GnomePieSliceLayerVisibility gnome_pie_slice_layer_get_visibility (GnomePieSliceLayer* self);
VALA_EXTERN GnomePieImage* gnome_pie_slice_layer_get_image (GnomePieSliceLayer* self);
VALA_EXTERN gboolean gnome_pie_slice_layer_get_colorize (GnomePieSliceLayer* self);
VALA_EXTERN const gchar* gnome_pie_slice_layer_get_font (GnomePieSliceLayer* self);
VALA_EXTERN gint gnome_pie_slice_layer_get_width (GnomePieSliceLayer* self);
VALA_EXTERN gint gnome_pie_slice_layer_get_height (GnomePieSliceLayer* self);
VALA_EXTERN gint gnome_pie_slice_layer_get_x (GnomePieSliceLayer* self);
VALA_EXTERN gint gnome_pie_slice_layer_get_y (GnomePieSliceLayer* self);
VALA_EXTERN GnomePieColor* gnome_pie_slice_layer_get_color (GnomePieSliceLayer* self);
static void gnome_pie_slice_layer_finalize (GObject * obj);
static GType gnome_pie_slice_layer_get_type_once (void);
static void _vala_gnome_pie_slice_layer_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);
static void _vala_gnome_pie_slice_layer_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec);

static inline gpointer
gnome_pie_slice_layer_get_instance_private (GnomePieSliceLayer* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePieSliceLayer_private_offset);
}

static GType
gnome_pie_slice_layer_type_get_type_once (void)
{
	static const GEnumValue values[] = {{GNOME_PIE_SLICE_LAYER_TYPE_FILE, "GNOME_PIE_SLICE_LAYER_TYPE_FILE", "file"}, {GNOME_PIE_SLICE_LAYER_TYPE_ICON, "GNOME_PIE_SLICE_LAYER_TYPE_ICON", "icon"}, {GNOME_PIE_SLICE_LAYER_TYPE_CAPTION, "GNOME_PIE_SLICE_LAYER_TYPE_CAPTION", "caption"}, {0, NULL, NULL}};
	GType gnome_pie_slice_layer_type_type_id;
	gnome_pie_slice_layer_type_type_id = g_enum_register_static ("GnomePieSliceLayerType", values);
	return gnome_pie_slice_layer_type_type_id;
}

GType
gnome_pie_slice_layer_type_get_type (void)
{
	static volatile gsize gnome_pie_slice_layer_type_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_slice_layer_type_type_id__once)) {
		GType gnome_pie_slice_layer_type_type_id;
		gnome_pie_slice_layer_type_type_id = gnome_pie_slice_layer_type_get_type_once ();
		g_once_init_leave (&gnome_pie_slice_layer_type_type_id__once, gnome_pie_slice_layer_type_type_id);
	}
	return gnome_pie_slice_layer_type_type_id__once;
}

static GType
gnome_pie_slice_layer_visibility_get_type_once (void)
{
	static const GEnumValue values[] = {{GNOME_PIE_SLICE_LAYER_VISIBILITY_ANY, "GNOME_PIE_SLICE_LAYER_VISIBILITY_ANY", "any"}, {GNOME_PIE_SLICE_LAYER_VISIBILITY_WITH_CAPTION, "GNOME_PIE_SLICE_LAYER_VISIBILITY_WITH_CAPTION", "with-caption"}, {GNOME_PIE_SLICE_LAYER_VISIBILITY_WITHOUT_CAPTION, "GNOME_PIE_SLICE_LAYER_VISIBILITY_WITHOUT_CAPTION", "without-caption"}, {0, NULL, NULL}};
	GType gnome_pie_slice_layer_visibility_type_id;
	gnome_pie_slice_layer_visibility_type_id = g_enum_register_static ("GnomePieSliceLayerVisibility", values);
	return gnome_pie_slice_layer_visibility_type_id;
}

GType
gnome_pie_slice_layer_visibility_get_type (void)
{
	static volatile gsize gnome_pie_slice_layer_visibility_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_slice_layer_visibility_type_id__once)) {
		GType gnome_pie_slice_layer_visibility_type_id;
		gnome_pie_slice_layer_visibility_type_id = gnome_pie_slice_layer_visibility_get_type_once ();
		g_once_init_leave (&gnome_pie_slice_layer_visibility_type_id__once, gnome_pie_slice_layer_visibility_type_id);
	}
	return gnome_pie_slice_layer_visibility_type_id__once;
}

GnomePieSliceLayer*
gnome_pie_slice_layer_construct_file (GType object_type,
                                      const gchar* icon_file,
                                      gint icon_size,
                                      gint x,
                                      gint y,
                                      gboolean colorize,
                                      GnomePieSliceLayerVisibility visibility)
{
	GnomePieSliceLayer * self = NULL;
	g_return_val_if_fail (icon_file != NULL, NULL);
	self = (GnomePieSliceLayer*) g_object_new (object_type, NULL);
	gnome_pie_slice_layer_set_layer_type (self, GNOME_PIE_SLICE_LAYER_TYPE_FILE);
	gnome_pie_slice_layer_set_icon_file (self, icon_file);
	gnome_pie_slice_layer_set_colorize (self, colorize);
	gnome_pie_slice_layer_set_icon_size (self, icon_size);
	gnome_pie_slice_layer_set_x (self, x);
	gnome_pie_slice_layer_set_y (self, y);
	gnome_pie_slice_layer_set_visibility (self, visibility);
	return self;
}

GnomePieSliceLayer*
gnome_pie_slice_layer_new_file (const gchar* icon_file,
                                gint icon_size,
                                gint x,
                                gint y,
                                gboolean colorize,
                                GnomePieSliceLayerVisibility visibility)
{
	return gnome_pie_slice_layer_construct_file (GNOME_PIE_TYPE_SLICE_LAYER, icon_file, icon_size, x, y, colorize, visibility);
}

GnomePieSliceLayer*
gnome_pie_slice_layer_construct_icon (GType object_type,
                                      const gchar* icon_file,
                                      gint icon_size,
                                      gint x,
                                      gint y,
                                      gboolean colorize,
                                      GnomePieSliceLayerVisibility visibility)
{
	GnomePieSliceLayer * self = NULL;
	g_return_val_if_fail (icon_file != NULL, NULL);
	self = (GnomePieSliceLayer*) g_object_new (object_type, NULL);
	gnome_pie_slice_layer_set_layer_type (self, GNOME_PIE_SLICE_LAYER_TYPE_ICON);
	gnome_pie_slice_layer_set_icon_file (self, icon_file);
	gnome_pie_slice_layer_set_colorize (self, colorize);
	gnome_pie_slice_layer_set_icon_size (self, icon_size);
	gnome_pie_slice_layer_set_x (self, x);
	gnome_pie_slice_layer_set_y (self, y);
	gnome_pie_slice_layer_set_visibility (self, visibility);
	return self;
}

GnomePieSliceLayer*
gnome_pie_slice_layer_new_icon (const gchar* icon_file,
                                gint icon_size,
                                gint x,
                                gint y,
                                gboolean colorize,
                                GnomePieSliceLayerVisibility visibility)
{
	return gnome_pie_slice_layer_construct_icon (GNOME_PIE_TYPE_SLICE_LAYER, icon_file, icon_size, x, y, colorize, visibility);
}

GnomePieSliceLayer*
gnome_pie_slice_layer_construct_caption (GType object_type,
                                         const gchar* font,
                                         gint width,
                                         gint height,
                                         gint x,
                                         gint y,
                                         GnomePieColor* color,
                                         gboolean colorize,
                                         GnomePieSliceLayerVisibility visibility)
{
	GnomePieSliceLayer * self = NULL;
	g_return_val_if_fail (font != NULL, NULL);
	g_return_val_if_fail (color != NULL, NULL);
	self = (GnomePieSliceLayer*) g_object_new (object_type, NULL);
	gnome_pie_slice_layer_set_layer_type (self, GNOME_PIE_SLICE_LAYER_TYPE_CAPTION);
	gnome_pie_slice_layer_set_font (self, font);
	gnome_pie_slice_layer_set_width (self, width);
	gnome_pie_slice_layer_set_height (self, height);
	gnome_pie_slice_layer_set_x (self, x);
	gnome_pie_slice_layer_set_y (self, y);
	gnome_pie_slice_layer_set_color (self, color);
	gnome_pie_slice_layer_set_visibility (self, visibility);
	gnome_pie_slice_layer_set_colorize (self, colorize);
	return self;
}

GnomePieSliceLayer*
gnome_pie_slice_layer_new_caption (const gchar* font,
                                   gint width,
                                   gint height,
                                   gint x,
                                   gint y,
                                   GnomePieColor* color,
                                   gboolean colorize,
                                   GnomePieSliceLayerVisibility visibility)
{
	return gnome_pie_slice_layer_construct_caption (GNOME_PIE_TYPE_SLICE_LAYER, font, width, height, x, y, color, colorize, visibility);
}

void
gnome_pie_slice_layer_load_image (GnomePieSliceLayer* self)
{
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	gnome_pie_slice_layer_set_image (self, NULL);
	_tmp1_ = self->priv->_icon_file;
	if (g_strcmp0 (_tmp1_, "") == 0) {
		GnomePieSliceLayerType _tmp2_;
		_tmp2_ = self->priv->_layer_type;
		_tmp0_ = _tmp2_ == GNOME_PIE_SLICE_LAYER_TYPE_ICON;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gint _tmp3_;
		gint _tmp4_;
		GnomePieColor* _tmp5_;
		GnomePieColor* _tmp6_;
		GnomePieImage* _tmp7_;
		GnomePieImage* _tmp8_;
		_tmp3_ = self->priv->_icon_size;
		_tmp4_ = self->priv->_icon_size;
		_tmp5_ = gnome_pie_color_new_from_rgb ((gfloat) 1, (gfloat) 1, (gfloat) 1);
		_tmp6_ = _tmp5_;
		_tmp7_ = gnome_pie_image_new_empty (_tmp3_, _tmp4_, _tmp6_);
		_tmp8_ = _tmp7_;
		gnome_pie_slice_layer_set_image (self, _tmp8_);
		_g_object_unref0 (_tmp8_);
		_g_object_unref0 (_tmp6_);
	} else {
		const gchar* _tmp9_;
		_tmp9_ = self->priv->_icon_file;
		if (g_strcmp0 (_tmp9_, "") != 0) {
			const gchar* _tmp10_;
			gint _tmp11_;
			gint _tmp12_;
			GnomePieImage* _tmp13_;
			GnomePieImage* _tmp14_;
			_tmp10_ = self->priv->_icon_file;
			_tmp11_ = self->priv->_icon_size;
			_tmp12_ = self->priv->_icon_size;
			_tmp13_ = gnome_pie_image_new_from_file_at_size (_tmp10_, _tmp11_, _tmp12_);
			_tmp14_ = _tmp13_;
			gnome_pie_slice_layer_set_image (self, _tmp14_);
			_g_object_unref0 (_tmp14_);
		}
	}
}

GnomePieSliceLayer*
gnome_pie_slice_layer_construct (GType object_type)
{
	GnomePieSliceLayer * self = NULL;
	self = (GnomePieSliceLayer*) g_object_new (object_type, NULL);
	return self;
}

GnomePieSliceLayer*
gnome_pie_slice_layer_new (void)
{
	return gnome_pie_slice_layer_construct (GNOME_PIE_TYPE_SLICE_LAYER);
}

GnomePieSliceLayerType
gnome_pie_slice_layer_get_layer_type (GnomePieSliceLayer* self)
{
	GnomePieSliceLayerType result;
	g_return_val_if_fail (self != NULL, 0);
	result = self->priv->_layer_type;
	return result;
}

static void
gnome_pie_slice_layer_set_layer_type (GnomePieSliceLayer* self,
                                      GnomePieSliceLayerType value)
{
	GnomePieSliceLayerType old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_layer_type (self);
	if (old_value != value) {
		self->priv->_layer_type = value;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_LAYER_TYPE_PROPERTY]);
	}
}

GnomePieSliceLayerVisibility
gnome_pie_slice_layer_get_visibility (GnomePieSliceLayer* self)
{
	GnomePieSliceLayerVisibility result;
	g_return_val_if_fail (self != NULL, 0);
	result = self->priv->_visibility;
	return result;
}

static void
gnome_pie_slice_layer_set_visibility (GnomePieSliceLayer* self,
                                      GnomePieSliceLayerVisibility value)
{
	GnomePieSliceLayerVisibility old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_visibility (self);
	if (old_value != value) {
		self->priv->_visibility = value;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_VISIBILITY_PROPERTY]);
	}
}

GnomePieImage*
gnome_pie_slice_layer_get_image (GnomePieSliceLayer* self)
{
	GnomePieImage* result;
	GnomePieImage* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_image;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
gnome_pie_slice_layer_set_image (GnomePieSliceLayer* self,
                                 GnomePieImage* value)
{
	GnomePieImage* old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_image (self);
	if (old_value != value) {
		GnomePieImage* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_image);
		self->priv->_image = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_IMAGE_PROPERTY]);
	}
}

const gchar*
gnome_pie_slice_layer_get_icon_file (GnomePieSliceLayer* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_icon_file;
	result = _tmp0_;
	return result;
}

static void
gnome_pie_slice_layer_set_icon_file (GnomePieSliceLayer* self,
                                     const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_icon_file (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_icon_file);
		self->priv->_icon_file = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_ICON_FILE_PROPERTY]);
	}
}

gboolean
gnome_pie_slice_layer_get_colorize (GnomePieSliceLayer* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_colorize;
	return result;
}

static void
gnome_pie_slice_layer_set_colorize (GnomePieSliceLayer* self,
                                    gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_colorize (self);
	if (old_value != value) {
		self->priv->_colorize = value;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_COLORIZE_PROPERTY]);
	}
}

gint
gnome_pie_slice_layer_get_icon_size (GnomePieSliceLayer* self)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_icon_size;
	return result;
}

static void
gnome_pie_slice_layer_set_icon_size (GnomePieSliceLayer* self,
                                     gint value)
{
	gint old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_icon_size (self);
	if (old_value != value) {
		self->priv->_icon_size = value;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_ICON_SIZE_PROPERTY]);
	}
}

const gchar*
gnome_pie_slice_layer_get_font (GnomePieSliceLayer* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_font;
	result = _tmp0_;
	return result;
}

static void
gnome_pie_slice_layer_set_font (GnomePieSliceLayer* self,
                                const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_font (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_font);
		self->priv->_font = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_FONT_PROPERTY]);
	}
}

gint
gnome_pie_slice_layer_get_width (GnomePieSliceLayer* self)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_width;
	return result;
}

static void
gnome_pie_slice_layer_set_width (GnomePieSliceLayer* self,
                                 gint value)
{
	gint old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_width (self);
	if (old_value != value) {
		self->priv->_width = value;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_WIDTH_PROPERTY]);
	}
}

gint
gnome_pie_slice_layer_get_height (GnomePieSliceLayer* self)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_height;
	return result;
}

static void
gnome_pie_slice_layer_set_height (GnomePieSliceLayer* self,
                                  gint value)
{
	gint old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_height (self);
	if (old_value != value) {
		self->priv->_height = value;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_HEIGHT_PROPERTY]);
	}
}

gint
gnome_pie_slice_layer_get_x (GnomePieSliceLayer* self)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_x;
	return result;
}

static void
gnome_pie_slice_layer_set_x (GnomePieSliceLayer* self,
                             gint value)
{
	gint old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_x (self);
	if (old_value != value) {
		self->priv->_x = value;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_X_PROPERTY]);
	}
}

gint
gnome_pie_slice_layer_get_y (GnomePieSliceLayer* self)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_y;
	return result;
}

static void
gnome_pie_slice_layer_set_y (GnomePieSliceLayer* self,
                             gint value)
{
	gint old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_y (self);
	if (old_value != value) {
		self->priv->_y = value;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_Y_PROPERTY]);
	}
}

GnomePieColor*
gnome_pie_slice_layer_get_color (GnomePieSliceLayer* self)
{
	GnomePieColor* result;
	GnomePieColor* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_color;
	result = _tmp0_;
	return result;
}

static void
gnome_pie_slice_layer_set_color (GnomePieSliceLayer* self,
                                 GnomePieColor* value)
{
	GnomePieColor* old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_slice_layer_get_color (self);
	if (old_value != value) {
		GnomePieColor* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_color);
		self->priv->_color = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_COLOR_PROPERTY]);
	}
}

static void
gnome_pie_slice_layer_class_init (GnomePieSliceLayerClass * klass,
                                  gpointer klass_data)
{
	gnome_pie_slice_layer_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GnomePieSliceLayer_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gnome_pie_slice_layer_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gnome_pie_slice_layer_set_property;
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_slice_layer_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_LAYER_TYPE_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_LAYER_TYPE_PROPERTY] = g_param_spec_enum ("layer-type", "layer-type", "layer-type", GNOME_PIE_SLICE_LAYER_TYPE_TYPE, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_VISIBILITY_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_VISIBILITY_PROPERTY] = g_param_spec_enum ("visibility", "visibility", "visibility", GNOME_PIE_SLICE_LAYER_TYPE_VISIBILITY, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_IMAGE_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_IMAGE_PROPERTY] = g_param_spec_object ("image", "image", "image", GNOME_PIE_TYPE_IMAGE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_ICON_FILE_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_ICON_FILE_PROPERTY] = g_param_spec_string ("icon-file", "icon-file", "icon-file", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_COLORIZE_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_COLORIZE_PROPERTY] = g_param_spec_boolean ("colorize", "colorize", "colorize", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_ICON_SIZE_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_ICON_SIZE_PROPERTY] = g_param_spec_int ("icon-size", "icon-size", "icon-size", G_MININT, G_MAXINT, 1, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_FONT_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_FONT_PROPERTY] = g_param_spec_string ("font", "font", "font", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_WIDTH_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_WIDTH_PROPERTY] = g_param_spec_int ("width", "width", "width", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_HEIGHT_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_HEIGHT_PROPERTY] = g_param_spec_int ("height", "height", "height", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_X_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_X_PROPERTY] = g_param_spec_int ("x", "x", "x", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_Y_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_Y_PROPERTY] = g_param_spec_int ("y", "y", "y", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_SLICE_LAYER_COLOR_PROPERTY, gnome_pie_slice_layer_properties[GNOME_PIE_SLICE_LAYER_COLOR_PROPERTY] = g_param_spec_object ("color", "color", "color", GNOME_PIE_TYPE_COLOR, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gnome_pie_slice_layer_instance_init (GnomePieSliceLayer * self,
                                     gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	GnomePieColor* _tmp2_;
	self->priv = gnome_pie_slice_layer_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_icon_file = _tmp0_;
	self->priv->_colorize = FALSE;
	self->priv->_icon_size = 1;
	_tmp1_ = g_strdup ("");
	self->priv->_font = _tmp1_;
	self->priv->_width = 0;
	self->priv->_height = 0;
	self->priv->_x = 0;
	self->priv->_y = 0;
	_tmp2_ = gnome_pie_color_new ();
	self->priv->_color = _tmp2_;
}

static void
gnome_pie_slice_layer_finalize (GObject * obj)
{
	GnomePieSliceLayer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_SLICE_LAYER, GnomePieSliceLayer);
	_g_object_unref0 (self->priv->_image);
	_g_free0 (self->priv->_icon_file);
	_g_free0 (self->priv->_font);
	_g_object_unref0 (self->priv->_color);
	G_OBJECT_CLASS (gnome_pie_slice_layer_parent_class)->finalize (obj);
}

static GType
gnome_pie_slice_layer_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieSliceLayerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_slice_layer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieSliceLayer), 0, (GInstanceInitFunc) gnome_pie_slice_layer_instance_init, NULL };
	GType gnome_pie_slice_layer_type_id;
	gnome_pie_slice_layer_type_id = g_type_register_static (G_TYPE_OBJECT, "GnomePieSliceLayer", &g_define_type_info, 0);
	GnomePieSliceLayer_private_offset = g_type_add_instance_private (gnome_pie_slice_layer_type_id, sizeof (GnomePieSliceLayerPrivate));
	return gnome_pie_slice_layer_type_id;
}

GType
gnome_pie_slice_layer_get_type (void)
{
	static volatile gsize gnome_pie_slice_layer_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_slice_layer_type_id__once)) {
		GType gnome_pie_slice_layer_type_id;
		gnome_pie_slice_layer_type_id = gnome_pie_slice_layer_get_type_once ();
		g_once_init_leave (&gnome_pie_slice_layer_type_id__once, gnome_pie_slice_layer_type_id);
	}
	return gnome_pie_slice_layer_type_id__once;
}

static void
_vala_gnome_pie_slice_layer_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	GnomePieSliceLayer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_SLICE_LAYER, GnomePieSliceLayer);
	switch (property_id) {
		case GNOME_PIE_SLICE_LAYER_LAYER_TYPE_PROPERTY:
		g_value_set_enum (value, gnome_pie_slice_layer_get_layer_type (self));
		break;
		case GNOME_PIE_SLICE_LAYER_VISIBILITY_PROPERTY:
		g_value_set_enum (value, gnome_pie_slice_layer_get_visibility (self));
		break;
		case GNOME_PIE_SLICE_LAYER_IMAGE_PROPERTY:
		g_value_set_object (value, gnome_pie_slice_layer_get_image (self));
		break;
		case GNOME_PIE_SLICE_LAYER_ICON_FILE_PROPERTY:
		g_value_set_string (value, gnome_pie_slice_layer_get_icon_file (self));
		break;
		case GNOME_PIE_SLICE_LAYER_COLORIZE_PROPERTY:
		g_value_set_boolean (value, gnome_pie_slice_layer_get_colorize (self));
		break;
		case GNOME_PIE_SLICE_LAYER_ICON_SIZE_PROPERTY:
		g_value_set_int (value, gnome_pie_slice_layer_get_icon_size (self));
		break;
		case GNOME_PIE_SLICE_LAYER_FONT_PROPERTY:
		g_value_set_string (value, gnome_pie_slice_layer_get_font (self));
		break;
		case GNOME_PIE_SLICE_LAYER_WIDTH_PROPERTY:
		g_value_set_int (value, gnome_pie_slice_layer_get_width (self));
		break;
		case GNOME_PIE_SLICE_LAYER_HEIGHT_PROPERTY:
		g_value_set_int (value, gnome_pie_slice_layer_get_height (self));
		break;
		case GNOME_PIE_SLICE_LAYER_X_PROPERTY:
		g_value_set_int (value, gnome_pie_slice_layer_get_x (self));
		break;
		case GNOME_PIE_SLICE_LAYER_Y_PROPERTY:
		g_value_set_int (value, gnome_pie_slice_layer_get_y (self));
		break;
		case GNOME_PIE_SLICE_LAYER_COLOR_PROPERTY:
		g_value_set_object (value, gnome_pie_slice_layer_get_color (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gnome_pie_slice_layer_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec)
{
	GnomePieSliceLayer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_SLICE_LAYER, GnomePieSliceLayer);
	switch (property_id) {
		case GNOME_PIE_SLICE_LAYER_LAYER_TYPE_PROPERTY:
		gnome_pie_slice_layer_set_layer_type (self, g_value_get_enum (value));
		break;
		case GNOME_PIE_SLICE_LAYER_VISIBILITY_PROPERTY:
		gnome_pie_slice_layer_set_visibility (self, g_value_get_enum (value));
		break;
		case GNOME_PIE_SLICE_LAYER_IMAGE_PROPERTY:
		gnome_pie_slice_layer_set_image (self, g_value_get_object (value));
		break;
		case GNOME_PIE_SLICE_LAYER_ICON_FILE_PROPERTY:
		gnome_pie_slice_layer_set_icon_file (self, g_value_get_string (value));
		break;
		case GNOME_PIE_SLICE_LAYER_COLORIZE_PROPERTY:
		gnome_pie_slice_layer_set_colorize (self, g_value_get_boolean (value));
		break;
		case GNOME_PIE_SLICE_LAYER_ICON_SIZE_PROPERTY:
		gnome_pie_slice_layer_set_icon_size (self, g_value_get_int (value));
		break;
		case GNOME_PIE_SLICE_LAYER_FONT_PROPERTY:
		gnome_pie_slice_layer_set_font (self, g_value_get_string (value));
		break;
		case GNOME_PIE_SLICE_LAYER_WIDTH_PROPERTY:
		gnome_pie_slice_layer_set_width (self, g_value_get_int (value));
		break;
		case GNOME_PIE_SLICE_LAYER_HEIGHT_PROPERTY:
		gnome_pie_slice_layer_set_height (self, g_value_get_int (value));
		break;
		case GNOME_PIE_SLICE_LAYER_X_PROPERTY:
		gnome_pie_slice_layer_set_x (self, g_value_get_int (value));
		break;
		case GNOME_PIE_SLICE_LAYER_Y_PROPERTY:
		gnome_pie_slice_layer_set_y (self, g_value_get_int (value));
		break;
		case GNOME_PIE_SLICE_LAYER_COLOR_PROPERTY:
		gnome_pie_slice_layer_set_color (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

