/* iconSelectWindow.c generated by valac 0.56.19, the Vala compiler
 * generated from iconSelectWindow.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <gio/gio.h>
#include <gobject/gvaluecollector.h>

#define GNOME_PIE_ICON_SELECT_WINDOW_disabled_contexts "Animations, FileSystems"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_ICON_SELECT_WINDOW (gnome_pie_icon_select_window_get_type ())
#define GNOME_PIE_ICON_SELECT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ICON_SELECT_WINDOW, GnomePieIconSelectWindow))
#define GNOME_PIE_ICON_SELECT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ICON_SELECT_WINDOW, GnomePieIconSelectWindowClass))
#define GNOME_PIE_IS_ICON_SELECT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ICON_SELECT_WINDOW))
#define GNOME_PIE_IS_ICON_SELECT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ICON_SELECT_WINDOW))
#define GNOME_PIE_ICON_SELECT_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ICON_SELECT_WINDOW, GnomePieIconSelectWindowClass))

typedef struct _GnomePieIconSelectWindow GnomePieIconSelectWindow;
typedef struct _GnomePieIconSelectWindowClass GnomePieIconSelectWindowClass;
typedef struct _GnomePieIconSelectWindowPrivate GnomePieIconSelectWindowPrivate;

#define GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY (gnome_pie_icon_select_window_list_entry_get_type ())
#define GNOME_PIE_ICON_SELECT_WINDOW_LIST_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY, GnomePieIconSelectWindowListEntry))
#define GNOME_PIE_ICON_SELECT_WINDOW_LIST_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY, GnomePieIconSelectWindowListEntryClass))
#define GNOME_PIE_ICON_SELECT_WINDOW_IS_LIST_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY))
#define GNOME_PIE_ICON_SELECT_WINDOW_IS_LIST_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY))
#define GNOME_PIE_ICON_SELECT_WINDOW_LIST_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY, GnomePieIconSelectWindowListEntryClass))

typedef struct _GnomePieIconSelectWindowListEntry GnomePieIconSelectWindowListEntry;
typedef struct _GnomePieIconSelectWindowListEntryClass GnomePieIconSelectWindowListEntryClass;
enum  {
	GNOME_PIE_ICON_SELECT_WINDOW_0_PROPERTY,
	GNOME_PIE_ICON_SELECT_WINDOW_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_icon_select_window_properties[GNOME_PIE_ICON_SELECT_WINDOW_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_async_queue_unref0(var) ((var == NULL) ? NULL : (var = (g_async_queue_unref (var), NULL)))
typedef struct _Block4Data Block4Data;
#define __vala_GtkTreePath_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block5Data Block5Data;
typedef struct _GnomePieIconSelectWindowListEntryPrivate GnomePieIconSelectWindowListEntryPrivate;
#define _gnome_pie_icon_select_window_list_entry_unref0(var) ((var == NULL) ? NULL : (var = (gnome_pie_icon_select_window_list_entry_unref (var), NULL)))
typedef struct _GnomePieIconSelectWindowLoadAllData GnomePieIconSelectWindowLoadAllData;
typedef struct _GnomePieIconSelectWindowParamSpecListEntry GnomePieIconSelectWindowParamSpecListEntry;
enum  {
	GNOME_PIE_ICON_SELECT_WINDOW_ON_OK_SIGNAL,
	GNOME_PIE_ICON_SELECT_WINDOW_NUM_SIGNALS
};
static guint gnome_pie_icon_select_window_signals[GNOME_PIE_ICON_SELECT_WINDOW_NUM_SIGNALS] = {0};

struct _GnomePieIconSelectWindow {
	GObject parent_instance;
	GnomePieIconSelectWindowPrivate * priv;
};

struct _GnomePieIconSelectWindowClass {
	GObjectClass parent_class;
};

struct _GnomePieIconSelectWindowPrivate {
	gchar* active_icon;
	GtkTreeModelFilter* icon_list_filtered;
	GtkIconView* icon_view;
	GtkSpinner* spinner;
	GtkFileChooserWidget* file_chooser;
	GtkNotebook* tabs;
	GtkWindow* window;
	GAsyncQueue* load_queue;
};

struct _Block4Data {
	int _ref_count_;
	GnomePieIconSelectWindow* self;
	GtkEntry* filter;
};

struct _Block5Data {
	int _ref_count_;
	GnomePieIconSelectWindow* self;
	gchar* icon;
};

struct _GnomePieIconSelectWindowListEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GnomePieIconSelectWindowListEntryPrivate * priv;
	gchar* name;
	GdkPixbuf* pixbuf;
};

struct _GnomePieIconSelectWindowListEntryClass {
	GTypeClass parent_class;
	void (*finalize) (GnomePieIconSelectWindowListEntry *self);
};

struct _GnomePieIconSelectWindowLoadAllData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GnomePieIconSelectWindow* self;
	GtkIconTheme* icon_theme;
	GtkIconTheme* _tmp0_;
	GtkIconTheme* _tmp1_;
	GtkIconTheme* _tmp2_;
	GList* _tmp3_;
	GList* icon_collection;
	GList* icon_it;
	gchar* _tmp4_;
	gchar* icon;
	GnomePieIconSelectWindowListEntry* new_entry;
	GnomePieIconSelectWindowListEntry* _tmp5_;
	GnomePieIconSelectWindowListEntry* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	GdkPixbuf* _tmp9_;
	GtkIconTheme* _tmp10_;
	const gchar* _tmp11_;
	GdkPixbuf* _tmp12_;
	GnomePieIconSelectWindowListEntry* _tmp13_;
	GdkPixbuf* _tmp14_;
	GAsyncQueue* _tmp15_;
	GnomePieIconSelectWindowListEntry* _tmp16_;
	GnomePieIconSelectWindowListEntry* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	GtkSpinner* _tmp21_;
	GtkSpinner* _tmp22_;
	GError* _inner_error0_;
};

struct _GnomePieIconSelectWindowParamSpecListEntry {
	GParamSpec parent_instance;
};

static gint GnomePieIconSelectWindow_private_offset;
static gpointer gnome_pie_icon_select_window_parent_class = NULL;
static GtkListStore* gnome_pie_icon_select_window_icon_list;
static GtkListStore* gnome_pie_icon_select_window_icon_list = NULL;
static gboolean gnome_pie_icon_select_window_loading;
static gboolean gnome_pie_icon_select_window_loading = FALSE;
static gboolean gnome_pie_icon_select_window_need_reload;
static gboolean gnome_pie_icon_select_window_need_reload = TRUE;
static gpointer gnome_pie_icon_select_window_list_entry_parent_class = NULL;

VALA_EXTERN GType gnome_pie_icon_select_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieIconSelectWindow, g_object_unref)
static gpointer gnome_pie_icon_select_window_list_entry_ref (gpointer instance);
static void gnome_pie_icon_select_window_list_entry_unref (gpointer instance);
static GParamSpec* gnome_pie_icon_select_window_param_spec_list_entry (const gchar* name,
                                                                const gchar* nick,
                                                                const gchar* blurb,
                                                                GType object_type,
                                                                GParamFlags flags) G_GNUC_UNUSED ;
static void gnome_pie_icon_select_window_value_set_list_entry (GValue* value,
                                                        gpointer v_object) G_GNUC_UNUSED ;
static void gnome_pie_icon_select_window_value_take_list_entry (GValue* value,
                                                         gpointer v_object) G_GNUC_UNUSED ;
static gpointer gnome_pie_icon_select_window_value_get_list_entry (const GValue* value) G_GNUC_UNUSED ;
static GType gnome_pie_icon_select_window_list_entry_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieIconSelectWindowListEntry, gnome_pie_icon_select_window_list_entry_unref)
VALA_EXTERN GnomePieIconSelectWindow* gnome_pie_icon_select_window_new (GtkWindow* parent);
VALA_EXTERN GnomePieIconSelectWindow* gnome_pie_icon_select_window_construct (GType object_type,
                                                                  GtkWindow* parent);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void _gnome_pie_icon_select_window_list_entry_unref0_ (gpointer var);
static gint ____lambda40_ (GnomePieIconSelectWindow* self);
static gint _____lambda40__gtk_tree_iter_compare_func (GtkTreeModel* model,
                                                GtkTreeIter* a,
                                                GtkTreeIter* b,
                                                gpointer self);
static void ____lambda41_ (GnomePieIconSelectWindow* self);
static void gnome_pie_icon_select_window_load_icons (GnomePieIconSelectWindow* self);
static void _____lambda41__gtk_icon_theme_changed (GtkIconTheme* _sender,
                                            gpointer self);
VALA_EXTERN const gchar* gnome_pie_paths_get_ui_files (void);
static void gnome_pie_icon_select_window_on_ok_button_clicked (GnomePieIconSelectWindow* self);
static void _gnome_pie_icon_select_window_on_ok_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                            gpointer self);
static void gnome_pie_icon_select_window_on_cancel_button_clicked (GnomePieIconSelectWindow* self);
static void _gnome_pie_icon_select_window_on_cancel_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                gpointer self);
static gboolean ___lambda43_ (Block4Data* _data4_,
                       GtkTreeModel* model,
                       GtkTreeIter* iter);
static gboolean ____lambda43__gtk_tree_model_filter_visible_func (GtkTreeModel* model,
                                                           GtkTreeIter* iter,
                                                           gpointer self);
static void ___lambda44_ (Block4Data* _data4_,
                   GtkEntryIconPosition pos,
                   GdkEvent* event);
static void ____lambda44__gtk_entry_icon_release (GtkEntry* _sender,
                                           GtkEntryIconPosition icon_pos,
                                           GdkEvent* event,
                                           gpointer self);
static void ___lambda45_ (GnomePieIconSelectWindow* self);
static void ____lambda45__g_object_notify (GObject* _sender,
                                    GParamSpec* pspec,
                                    gpointer self);
static void ___lambda46_ (GnomePieIconSelectWindow* self);
static GtkTreePath* _vala_GtkTreePath_copy (GtkTreePath* self);
static void _vala_GtkTreePath_free (GtkTreePath* self);
static void __vala_GtkTreePath_free0_ (gpointer var);
static inline void _g_list_free___vala_GtkTreePath_free0_ (GList* self);
static void ____lambda46__gtk_icon_view_selection_changed (GtkIconView* _sender,
                                                    gpointer self);
static void ___lambda47_ (GnomePieIconSelectWindow* self,
                   GtkTreePath* path);
static void ____lambda47__gtk_icon_view_item_activated (GtkIconView* _sender,
                                                 GtkTreePath* path,
                                                 gpointer self);
static void ___lambda48_ (GnomePieIconSelectWindow* self);
static void ____lambda48__gtk_file_chooser_selection_changed (GtkFileChooser* _sender,
                                                       gpointer self);
static void ___lambda49_ (GnomePieIconSelectWindow* self);
static void ____lambda49__gtk_file_chooser_file_activated (GtkFileChooser* _sender,
                                                    gpointer self);
static gboolean _gtk_widget_hide_on_delete_gtk_widget_delete_event (GtkWidget* _sender,
                                                             GdkEventAny* event,
                                                             gpointer self);
VALA_EXTERN void gnome_pie_icon_select_window_show (GnomePieIconSelectWindow* self);
VALA_EXTERN void gnome_pie_icon_select_window_clear_icons (void);
VALA_EXTERN void gnome_pie_icon_select_window_set_icon (GnomePieIconSelectWindow* self,
                                            const gchar* icon);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static gboolean ___lambda50_ (Block5Data* _data5_,
                       GtkTreeModel* model,
                       GtkTreePath* path,
                       GtkTreeIter* iter);
static gboolean ____lambda50__gtk_tree_model_foreach_func (GtkTreeModel* model,
                                                    GtkTreePath* path,
                                                    GtkTreeIter* iter,
                                                    gpointer self);
static void gnome_pie_icon_select_window_load_all (GnomePieIconSelectWindow* self,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
static void gnome_pie_icon_select_window_load_all_finish (GnomePieIconSelectWindow* self,
                                                   GAsyncResult* _res_);
static gboolean ___lambda42_ (GnomePieIconSelectWindow* self);
static gboolean ____lambda42__gsource_func (gpointer self);
static void gnome_pie_icon_select_window_load_all_data_free (gpointer _data);
static gboolean gnome_pie_icon_select_window_load_all_co (GnomePieIconSelectWindowLoadAllData* _data_);
static gboolean _gnome_pie_icon_select_window_load_all_co_gsource_func (gpointer self);
static GnomePieIconSelectWindowListEntry* gnome_pie_icon_select_window_list_entry_new (void);
static GnomePieIconSelectWindowListEntry* gnome_pie_icon_select_window_list_entry_construct (GType object_type);
static void _g_free0_ (gpointer var);
static inline void _g_list_free__g_free0_ (GList* self);
static void gnome_pie_icon_select_window_list_entry_finalize (GnomePieIconSelectWindowListEntry * obj);
static GType gnome_pie_icon_select_window_list_entry_get_type_once (void);
static void gnome_pie_icon_select_window_finalize (GObject * obj);
static GType gnome_pie_icon_select_window_get_type_once (void);

static inline gpointer
gnome_pie_icon_select_window_get_instance_private (GnomePieIconSelectWindow* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePieIconSelectWindow_private_offset);
}

static Block4Data*
block4_data_ref (Block4Data* _data4_)
{
	g_atomic_int_inc (&_data4_->_ref_count_);
	return _data4_;
}

static void
block4_data_unref (void * _userdata_)
{
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
		GnomePieIconSelectWindow* self;
		self = _data4_->self;
		_g_object_unref0 (_data4_->filter);
		_g_object_unref0 (self);
		g_slice_free (Block4Data, _data4_);
	}
}

static void
_gnome_pie_icon_select_window_list_entry_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (gnome_pie_icon_select_window_list_entry_unref (var), NULL));
}

static gint
____lambda40_ (GnomePieIconSelectWindow* self)
{
	gint result;
	result = 0;
	return result;
}

static gint
_____lambda40__gtk_tree_iter_compare_func (GtkTreeModel* model,
                                           GtkTreeIter* a,
                                           GtkTreeIter* b,
                                           gpointer self)
{
	gint result;
	result = ____lambda40_ ((GnomePieIconSelectWindow*) self);
	return result;
}

static void
____lambda41_ (GnomePieIconSelectWindow* self)
{
	GtkWindow* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	_tmp0_ = self->priv->window;
	_tmp1_ = gtk_widget_get_visible ((GtkWidget*) _tmp0_);
	_tmp2_ = _tmp1_;
	if (_tmp2_) {
		gnome_pie_icon_select_window_load_icons (self);
	} else {
		gnome_pie_icon_select_window_need_reload = TRUE;
	}
}

static void
_____lambda41__gtk_icon_theme_changed (GtkIconTheme* _sender,
                                       gpointer self)
{
	____lambda41_ ((GnomePieIconSelectWindow*) self);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_gnome_pie_icon_select_window_on_ok_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                       gpointer self)
{
	gnome_pie_icon_select_window_on_ok_button_clicked ((GnomePieIconSelectWindow*) self);
}

static void
_gnome_pie_icon_select_window_on_cancel_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                           gpointer self)
{
	gnome_pie_icon_select_window_on_cancel_button_clicked ((GnomePieIconSelectWindow*) self);
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
	result = _tmp0_ != NULL;
	return result;
}

static gboolean
___lambda43_ (Block4Data* _data4_,
              GtkTreeModel* model,
              GtkTreeIter* iter)
{
	GnomePieIconSelectWindow* self;
	gchar* name = NULL;
	gchar* _tmp0_;
	GtkTreeIter _tmp1_;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gboolean _tmp11_;
	gboolean result;
	self = _data4_->self;
	g_return_val_if_fail (model != NULL, FALSE);
	g_return_val_if_fail (iter != NULL, FALSE);
	_tmp0_ = g_strdup ("");
	name = _tmp0_;
	_tmp1_ = *iter;
	gtk_tree_model_get (model, &_tmp1_, 0, &_tmp2_, -1);
	_g_free0 (name);
	name = _tmp2_;
	_tmp3_ = name;
	if (_tmp3_ == NULL) {
		result = FALSE;
		_g_free0 (name);
		return result;
	}
	_tmp4_ = name;
	_tmp5_ = g_utf8_strdown (_tmp4_, (gssize) -1);
	_tmp6_ = _tmp5_;
	_tmp7_ = gtk_entry_get_text (_data4_->filter);
	_tmp8_ = _tmp7_;
	_tmp9_ = g_utf8_strdown (_tmp8_, (gssize) -1);
	_tmp10_ = _tmp9_;
	_tmp11_ = string_contains (_tmp6_, _tmp10_);
	_g_free0 (_tmp10_);
	_g_free0 (_tmp6_);
	result = _tmp11_;
	_g_free0 (name);
	return result;
}

static gboolean
____lambda43__gtk_tree_model_filter_visible_func (GtkTreeModel* model,
                                                  GtkTreeIter* iter,
                                                  gpointer self)
{
	gboolean result;
	result = ___lambda43_ (self, model, iter);
	return result;
}

static void
___lambda44_ (Block4Data* _data4_,
              GtkEntryIconPosition pos,
              GdkEvent* event)
{
	GnomePieIconSelectWindow* self;
	self = _data4_->self;
	g_return_if_fail (event != NULL);
	if (pos == GTK_ENTRY_ICON_SECONDARY) {
		gtk_entry_set_text (_data4_->filter, "");
	}
}

static void
____lambda44__gtk_entry_icon_release (GtkEntry* _sender,
                                      GtkEntryIconPosition icon_pos,
                                      GdkEvent* event,
                                      gpointer self)
{
	___lambda44_ (self, icon_pos, event);
}

static void
___lambda45_ (GnomePieIconSelectWindow* self)
{
	GtkTreeModelFilter* _tmp0_;
	_tmp0_ = self->priv->icon_list_filtered;
	gtk_tree_model_filter_refilter (_tmp0_);
}

static void
____lambda45__g_object_notify (GObject* _sender,
                               GParamSpec* pspec,
                               gpointer self)
{
	___lambda45_ ((GnomePieIconSelectWindow*) self);
}

static GtkTreePath*
_vala_GtkTreePath_copy (GtkTreePath* self)
{
	return g_boxed_copy (gtk_tree_path_get_type (), self);
}

static gpointer
__vala_GtkTreePath_copy0 (gpointer self)
{
	return self ? _vala_GtkTreePath_copy (self) : NULL;
}

static void
_vala_GtkTreePath_free (GtkTreePath* self)
{
	g_boxed_free (gtk_tree_path_get_type (), self);
}

static void
__vala_GtkTreePath_free0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL));
}

static inline void
_g_list_free___vala_GtkTreePath_free0_ (GList* self)
{
	g_list_free_full (self, (GDestroyNotify) __vala_GtkTreePath_free0_);
}

static void
___lambda46_ (GnomePieIconSelectWindow* self)
{
	GtkIconView* _tmp0_;
	GList* _tmp1_;
	_tmp0_ = self->priv->icon_view;
	_tmp1_ = gtk_icon_view_get_selected_items (_tmp0_);
	{
		GList* path_collection = NULL;
		GList* path_it = NULL;
		path_collection = _tmp1_;
		for (path_it = path_collection; path_it != NULL; path_it = path_it->next) {
			GtkTreePath* _tmp2_;
			GtkTreePath* path = NULL;
			_tmp2_ = __vala_GtkTreePath_copy0 ((GtkTreePath*) path_it->data);
			path = _tmp2_;
			{
				GtkTreeIter iter = {0};
				GtkTreeModelFilter* _tmp3_;
				GtkTreePath* _tmp4_;
				GtkTreeIter _tmp5_ = {0};
				GtkTreeModelFilter* _tmp6_;
				GtkTreeIter _tmp7_;
				gchar* _tmp8_ = NULL;
				_tmp3_ = self->priv->icon_list_filtered;
				_tmp4_ = path;
				gtk_tree_model_get_iter ((GtkTreeModel*) _tmp3_, &_tmp5_, _tmp4_);
				iter = _tmp5_;
				_tmp6_ = self->priv->icon_list_filtered;
				_tmp7_ = iter;
				gtk_tree_model_get ((GtkTreeModel*) _tmp6_, &_tmp7_, 0, &_tmp8_, -1);
				_g_free0 (self->priv->active_icon);
				self->priv->active_icon = _tmp8_;
				__vala_GtkTreePath_free0 (path);
			}
		}
		(path_collection == NULL) ? NULL : (path_collection = (_g_list_free___vala_GtkTreePath_free0_ (path_collection), NULL));
	}
}

static void
____lambda46__gtk_icon_view_selection_changed (GtkIconView* _sender,
                                               gpointer self)
{
	___lambda46_ ((GnomePieIconSelectWindow*) self);
}

static void
___lambda47_ (GnomePieIconSelectWindow* self,
              GtkTreePath* path)
{
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	GtkTreeModelFilter* _tmp2_;
	GtkTreeIter _tmp3_;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_;
	GtkWindow* _tmp6_;
	g_return_if_fail (path != NULL);
	_tmp0_ = self->priv->icon_list_filtered;
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp1_, path);
	iter = _tmp1_;
	_tmp2_ = self->priv->icon_list_filtered;
	_tmp3_ = iter;
	gtk_tree_model_get ((GtkTreeModel*) _tmp2_, &_tmp3_, 0, &_tmp4_, -1);
	_g_free0 (self->priv->active_icon);
	self->priv->active_icon = _tmp4_;
	_tmp5_ = self->priv->active_icon;
	g_signal_emit (self, gnome_pie_icon_select_window_signals[GNOME_PIE_ICON_SELECT_WINDOW_ON_OK_SIGNAL], 0, _tmp5_);
	_tmp6_ = self->priv->window;
	gtk_widget_hide ((GtkWidget*) _tmp6_);
}

static void
____lambda47__gtk_icon_view_item_activated (GtkIconView* _sender,
                                            GtkTreePath* path,
                                            gpointer self)
{
	___lambda47_ ((GnomePieIconSelectWindow*) self, path);
}

static void
___lambda48_ (GnomePieIconSelectWindow* self)
{
	gboolean _tmp0_ = FALSE;
	GtkFileChooserWidget* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
	_tmp1_ = self->priv->file_chooser;
	_tmp2_ = gtk_file_chooser_get_filename ((GtkFileChooser*) _tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ != NULL;
	_g_free0 (_tmp3_);
	if (_tmp4_) {
		GtkFileChooserWidget* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		_tmp5_ = self->priv->file_chooser;
		_tmp6_ = gtk_file_chooser_get_filename ((GtkFileChooser*) _tmp5_);
		_tmp7_ = _tmp6_;
		_tmp0_ = g_file_test (_tmp7_, G_FILE_TEST_IS_REGULAR);
		_g_free0 (_tmp7_);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		GtkFileChooserWidget* _tmp8_;
		gchar* _tmp9_;
		_tmp8_ = self->priv->file_chooser;
		_tmp9_ = gtk_file_chooser_get_filename ((GtkFileChooser*) _tmp8_);
		_g_free0 (self->priv->active_icon);
		self->priv->active_icon = _tmp9_;
	}
}

static void
____lambda48__gtk_file_chooser_selection_changed (GtkFileChooser* _sender,
                                                  gpointer self)
{
	___lambda48_ ((GnomePieIconSelectWindow*) self);
}

static void
___lambda49_ (GnomePieIconSelectWindow* self)
{
	GtkFileChooserWidget* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	GtkWindow* _tmp3_;
	_tmp0_ = self->priv->file_chooser;
	_tmp1_ = gtk_file_chooser_get_filename ((GtkFileChooser*) _tmp0_);
	_g_free0 (self->priv->active_icon);
	self->priv->active_icon = _tmp1_;
	_tmp2_ = self->priv->active_icon;
	g_signal_emit (self, gnome_pie_icon_select_window_signals[GNOME_PIE_ICON_SELECT_WINDOW_ON_OK_SIGNAL], 0, _tmp2_);
	_tmp3_ = self->priv->window;
	gtk_widget_hide ((GtkWidget*) _tmp3_);
}

static void
____lambda49__gtk_file_chooser_file_activated (GtkFileChooser* _sender,
                                               gpointer self)
{
	___lambda49_ ((GnomePieIconSelectWindow*) self);
}

static gboolean
_gtk_widget_hide_on_delete_gtk_widget_delete_event (GtkWidget* _sender,
                                                    GdkEventAny* event,
                                                    gpointer self)
{
	gboolean result;
	result = gtk_widget_hide_on_delete ((GtkWidget*) self);
	return result;
}

GnomePieIconSelectWindow*
gnome_pie_icon_select_window_construct (GType object_type,
                                        GtkWindow* parent)
{
	GnomePieIconSelectWindow * self = NULL;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (parent != NULL, NULL);
	self = (GnomePieIconSelectWindow*) g_object_new (object_type, NULL);
	{
		Block4Data* _data4_;
		GAsyncQueue* _tmp0_;
		GtkListStore* _tmp1_;
		GtkListStore* _tmp5_;
		GtkTreeModelFilter* _tmp6_;
		GtkBuilder* builder = NULL;
		GtkBuilder* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GObject* _tmp12_;
		GtkWindow* _tmp13_;
		GtkWindow* _tmp14_;
		GtkWindow* _tmp15_;
		GObject* _tmp16_;
		GtkNotebook* _tmp17_;
		GObject* _tmp18_;
		GtkSpinner* _tmp19_;
		GtkSpinner* _tmp20_;
		GObject* _tmp21_;
		GObject* _tmp22_;
		GObject* _tmp23_;
		GtkEntry* _tmp24_;
		GtkTreeModelFilter* _tmp25_;
		GtkScrolledWindow* scroll = NULL;
		GObject* _tmp26_;
		GtkScrolledWindow* _tmp27_;
		GtkTreeModelFilter* _tmp28_;
		GtkIconView* _tmp29_;
		GtkIconView* _tmp30_;
		GtkIconView* _tmp31_;
		GtkIconView* _tmp32_;
		GtkIconView* _tmp33_;
		GtkIconView* _tmp34_;
		GtkIconView* _tmp35_;
		GtkIconView* _tmp36_;
		GObject* _tmp37_;
		GtkFileChooserWidget* _tmp38_;
		GtkFileFilter* file_filter = NULL;
		GtkFileFilter* _tmp39_;
		GtkFileChooserWidget* _tmp40_;
		GtkFileFilter* _tmp41_;
		GtkFileChooserWidget* _tmp42_;
		GtkFileChooserWidget* _tmp43_;
		GtkWindow* _tmp44_;
		GtkIconView* _tmp45_;
		GtkWindow* _tmp46_;
		GtkWindow* _tmp47_;
		_data4_ = g_slice_new0 (Block4Data);
		_data4_->_ref_count_ = 1;
		_data4_->self = g_object_ref (self);
		_tmp0_ = g_async_queue_new_full (_gnome_pie_icon_select_window_list_entry_unref0_);
		_g_async_queue_unref0 (self->priv->load_queue);
		self->priv->load_queue = _tmp0_;
		_tmp1_ = gnome_pie_icon_select_window_icon_list;
		if (_tmp1_ == NULL) {
			GtkListStore* _tmp2_;
			GtkListStore* _tmp3_;
			GtkIconTheme* _tmp4_;
			_tmp2_ = gtk_list_store_new (2, G_TYPE_STRING, gdk_pixbuf_get_type (), -1);
			_g_object_unref0 (gnome_pie_icon_select_window_icon_list);
			gnome_pie_icon_select_window_icon_list = _tmp2_;
			_tmp3_ = gnome_pie_icon_select_window_icon_list;
			gtk_tree_sortable_set_default_sort_func ((GtkTreeSortable*) _tmp3_, _____lambda40__gtk_tree_iter_compare_func, g_object_ref (self), g_object_unref);
			_tmp4_ = gtk_icon_theme_get_default ();
			g_signal_connect_object (_tmp4_, "changed", (GCallback) _____lambda41__gtk_icon_theme_changed, self, 0);
		}
		_tmp5_ = gnome_pie_icon_select_window_icon_list;
		_tmp6_ = (GtkTreeModelFilter*) gtk_tree_model_filter_new ((GtkTreeModel*) _tmp5_, NULL);
		_g_object_unref0 (self->priv->icon_list_filtered);
		self->priv->icon_list_filtered = _tmp6_;
		_tmp7_ = gtk_builder_new ();
		builder = _tmp7_;
		_tmp8_ = gnome_pie_paths_get_ui_files ();
		_tmp9_ = _tmp8_;
		_tmp10_ = g_strconcat (_tmp9_, "/icon_select.ui", NULL);
		_tmp11_ = _tmp10_;
		gtk_builder_add_from_file (builder, _tmp11_, &_inner_error0_);
		_g_free0 (_tmp11_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_object_unref0 (builder);
			block4_data_unref (_data4_);
			_data4_ = NULL;
			goto __catch0_g_error;
		}
		_tmp12_ = gtk_builder_get_object (builder, "window");
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, gtk_window_get_type ()) ? ((GtkWindow*) _tmp12_) : NULL);
		_g_object_unref0 (self->priv->window);
		self->priv->window = _tmp13_;
		_tmp14_ = self->priv->window;
		gtk_window_set_transient_for (_tmp14_, parent);
		_tmp15_ = self->priv->window;
		gtk_window_set_modal (_tmp15_, TRUE);
		_tmp16_ = gtk_builder_get_object (builder, "tabs");
		_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, gtk_notebook_get_type ()) ? ((GtkNotebook*) _tmp16_) : NULL);
		_g_object_unref0 (self->priv->tabs);
		self->priv->tabs = _tmp17_;
		_tmp18_ = gtk_builder_get_object (builder, "spinner");
		_tmp19_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, gtk_spinner_get_type ()) ? ((GtkSpinner*) _tmp18_) : NULL);
		_g_object_unref0 (self->priv->spinner);
		self->priv->spinner = _tmp19_;
		_tmp20_ = self->priv->spinner;
		gtk_spinner_start (_tmp20_);
		_tmp21_ = gtk_builder_get_object (builder, "ok-button");
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, gtk_button_get_type ()) ? ((GtkButton*) _tmp21_) : NULL, "clicked", (GCallback) _gnome_pie_icon_select_window_on_ok_button_clicked_gtk_button_clicked, self, 0);
		_tmp22_ = gtk_builder_get_object (builder, "cancel-button");
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, gtk_button_get_type ()) ? ((GtkButton*) _tmp22_) : NULL, "clicked", (GCallback) _gnome_pie_icon_select_window_on_cancel_button_clicked_gtk_button_clicked, self, 0);
		_tmp23_ = gtk_builder_get_object (builder, "filter-entry");
		_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp23_) : NULL);
		_data4_->filter = _tmp24_;
		_tmp25_ = self->priv->icon_list_filtered;
		gtk_tree_model_filter_set_visible_func (_tmp25_, ____lambda43__gtk_tree_model_filter_visible_func, block4_data_ref (_data4_), block4_data_unref);
		g_signal_connect_data (_data4_->filter, "icon-release", (GCallback) ____lambda44__gtk_entry_icon_release, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
		g_signal_connect_object ((GObject*) _data4_->filter, "notify::text", (GCallback) ____lambda45__g_object_notify, self, 0);
		_tmp26_ = gtk_builder_get_object (builder, "icon-scrolledwindow");
		_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, gtk_scrolled_window_get_type ()) ? ((GtkScrolledWindow*) _tmp26_) : NULL);
		scroll = _tmp27_;
		_tmp28_ = self->priv->icon_list_filtered;
		_tmp29_ = (GtkIconView*) gtk_icon_view_new_with_model ((GtkTreeModel*) _tmp28_);
		g_object_ref_sink (_tmp29_);
		_g_object_unref0 (self->priv->icon_view);
		self->priv->icon_view = _tmp29_;
		_tmp30_ = self->priv->icon_view;
		gtk_icon_view_set_item_width (_tmp30_, 32);
		_tmp31_ = self->priv->icon_view;
		gtk_icon_view_set_item_padding (_tmp31_, 2);
		_tmp32_ = self->priv->icon_view;
		gtk_icon_view_set_pixbuf_column (_tmp32_, 1);
		_tmp33_ = self->priv->icon_view;
		gtk_icon_view_set_tooltip_column (_tmp33_, 0);
		_tmp34_ = self->priv->icon_view;
		g_signal_connect_object (_tmp34_, "selection-changed", (GCallback) ____lambda46__gtk_icon_view_selection_changed, self, 0);
		_tmp35_ = self->priv->icon_view;
		g_signal_connect_object (_tmp35_, "item-activated", (GCallback) ____lambda47__gtk_icon_view_item_activated, self, 0);
		_tmp36_ = self->priv->icon_view;
		gtk_container_add ((GtkContainer*) scroll, (GtkWidget*) _tmp36_);
		_tmp37_ = gtk_builder_get_object (builder, "filechooser");
		_tmp38_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, gtk_file_chooser_widget_get_type ()) ? ((GtkFileChooserWidget*) _tmp37_) : NULL);
		_g_object_unref0 (self->priv->file_chooser);
		self->priv->file_chooser = _tmp38_;
		_tmp39_ = gtk_file_filter_new ();
		g_object_ref_sink (_tmp39_);
		file_filter = _tmp39_;
		gtk_file_filter_add_pixbuf_formats (file_filter);
		gtk_file_filter_set_name (file_filter, _ ("All supported image formats"));
		_tmp40_ = self->priv->file_chooser;
		_tmp41_ = _g_object_ref0 (file_filter);
		gtk_file_chooser_add_filter ((GtkFileChooser*) _tmp40_, _tmp41_);
		_tmp42_ = self->priv->file_chooser;
		g_signal_connect_object ((GtkFileChooser*) _tmp42_, "selection-changed", (GCallback) ____lambda48__gtk_file_chooser_selection_changed, self, 0);
		_tmp43_ = self->priv->file_chooser;
		g_signal_connect_object ((GtkFileChooser*) _tmp43_, "file-activated", (GCallback) ____lambda49__gtk_file_chooser_file_activated, self, 0);
		_tmp44_ = self->priv->window;
		_tmp45_ = self->priv->icon_view;
		gtk_window_set_focus (_tmp44_, (GtkWidget*) _tmp45_);
		_tmp46_ = self->priv->window;
		_tmp47_ = self->priv->window;
		g_signal_connect_object ((GtkWidget*) _tmp46_, "delete-event", (GCallback) _gtk_widget_hide_on_delete_gtk_widget_delete_event, (GtkWidget*) _tmp47_, 0);
		_g_object_unref0 (file_filter);
		_g_object_unref0 (scroll);
		_g_object_unref0 (builder);
		block4_data_unref (_data4_);
		_data4_ = NULL;
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp48_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp48_ = e->message;
		g_error ("iconSelectWindow.vala:249: Could not load UI: %s\n", _tmp48_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return NULL;
	}
	return self;
}

GnomePieIconSelectWindow*
gnome_pie_icon_select_window_new (GtkWindow* parent)
{
	return gnome_pie_icon_select_window_construct (GNOME_PIE_TYPE_ICON_SELECT_WINDOW, parent);
}

void
gnome_pie_icon_select_window_show (GnomePieIconSelectWindow* self)
{
	GtkWindow* _tmp0_;
	GtkSpinner* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->window;
	gtk_widget_show_all ((GtkWidget*) _tmp0_);
	_tmp1_ = self->priv->spinner;
	gtk_widget_hide ((GtkWidget*) _tmp1_);
	if (gnome_pie_icon_select_window_need_reload) {
		gnome_pie_icon_select_window_need_reload = FALSE;
		gnome_pie_icon_select_window_load_icons (self);
	}
}

void
gnome_pie_icon_select_window_clear_icons (void)
{
	GtkListStore* _tmp0_;
	_tmp0_ = gnome_pie_icon_select_window_icon_list;
	if (_tmp0_ != NULL) {
		GtkListStore* _tmp1_;
		gnome_pie_icon_select_window_need_reload = TRUE;
		_tmp1_ = gnome_pie_icon_select_window_icon_list;
		gtk_list_store_clear (_tmp1_);
	}
}

static Block5Data*
block5_data_ref (Block5Data* _data5_)
{
	g_atomic_int_inc (&_data5_->_ref_count_);
	return _data5_;
}

static void
block5_data_unref (void * _userdata_)
{
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
		GnomePieIconSelectWindow* self;
		self = _data5_->self;
		_g_free0 (_data5_->icon);
		_g_object_unref0 (self);
		g_slice_free (Block5Data, _data5_);
	}
}

static gboolean
___lambda50_ (Block5Data* _data5_,
              GtkTreeModel* model,
              GtkTreePath* path,
              GtkTreeIter* iter)
{
	GnomePieIconSelectWindow* self;
	gchar* name = NULL;
	gchar* _tmp0_;
	GtkTreeIter _tmp1_;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_;
	const gchar* _tmp7_;
	gboolean result;
	self = _data5_->self;
	g_return_val_if_fail (model != NULL, FALSE);
	g_return_val_if_fail (path != NULL, FALSE);
	g_return_val_if_fail (iter != NULL, FALSE);
	_tmp0_ = g_strdup ("");
	name = _tmp0_;
	_tmp1_ = *iter;
	gtk_tree_model_get (model, &_tmp1_, 0, &_tmp2_, -1);
	_g_free0 (name);
	name = _tmp2_;
	_tmp3_ = name;
	if (g_strcmp0 (_tmp3_, _data5_->icon) == 0) {
		GtkIconView* _tmp4_;
		GtkIconView* _tmp5_;
		GtkIconView* _tmp6_;
		_tmp4_ = self->priv->icon_view;
		gtk_icon_view_select_path (_tmp4_, path);
		_tmp5_ = self->priv->icon_view;
		gtk_icon_view_scroll_to_path (_tmp5_, path, TRUE, 0.5f, 0.0f);
		_tmp6_ = self->priv->icon_view;
		gtk_icon_view_set_cursor (_tmp6_, path, NULL, FALSE);
	}
	_tmp7_ = name;
	result = g_strcmp0 (_tmp7_, _data5_->icon) == 0;
	_g_free0 (name);
	return result;
}

static gboolean
____lambda50__gtk_tree_model_foreach_func (GtkTreeModel* model,
                                           GtkTreePath* path,
                                           GtkTreeIter* iter,
                                           gpointer self)
{
	gboolean result;
	result = ___lambda50_ (self, model, path, iter);
	return result;
}

void
gnome_pie_icon_select_window_set_icon (GnomePieIconSelectWindow* self,
                                       const gchar* icon)
{
	Block5Data* _data5_;
	gchar* _tmp0_;
	gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (icon != NULL);
	_data5_ = g_slice_new0 (Block5Data);
	_data5_->_ref_count_ = 1;
	_data5_->self = g_object_ref (self);
	_tmp0_ = g_strdup (icon);
	_g_free0 (_data5_->icon);
	_data5_->icon = _tmp0_;
	_tmp1_ = g_strdup (_data5_->icon);
	_g_free0 (self->priv->active_icon);
	self->priv->active_icon = _tmp1_;
	if (string_contains (_data5_->icon, "/")) {
		GtkFileChooserWidget* _tmp2_;
		GtkNotebook* _tmp3_;
		_tmp2_ = self->priv->file_chooser;
		gtk_file_chooser_set_filename ((GtkFileChooser*) _tmp2_, _data5_->icon);
		_tmp3_ = self->priv->tabs;
		gtk_notebook_set_current_page (_tmp3_, 1);
	} else {
		GtkTreeModelFilter* _tmp4_;
		GtkNotebook* _tmp5_;
		_tmp4_ = self->priv->icon_list_filtered;
		gtk_tree_model_foreach ((GtkTreeModel*) _tmp4_, ____lambda50__gtk_tree_model_foreach_func, _data5_);
		_tmp5_ = self->priv->tabs;
		gtk_notebook_set_current_page (_tmp5_, 0);
	}
	block5_data_unref (_data5_);
	_data5_ = NULL;
}

static void
gnome_pie_icon_select_window_on_ok_button_clicked (GnomePieIconSelectWindow* self)
{
	const gchar* _tmp0_;
	GtkWindow* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->active_icon;
	g_signal_emit (self, gnome_pie_icon_select_window_signals[GNOME_PIE_ICON_SELECT_WINDOW_ON_OK_SIGNAL], 0, _tmp0_);
	_tmp1_ = self->priv->window;
	gtk_widget_hide ((GtkWidget*) _tmp1_);
}

static void
gnome_pie_icon_select_window_on_cancel_button_clicked (GnomePieIconSelectWindow* self)
{
	GtkWindow* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->window;
	gtk_widget_hide ((GtkWidget*) _tmp0_);
}

static gboolean
___lambda42_ (GnomePieIconSelectWindow* self)
{
	gboolean result;
	while (TRUE) {
		GAsyncQueue* _tmp0_;
		GnomePieIconSelectWindowListEntry* new_entry = NULL;
		GAsyncQueue* _tmp1_;
		gpointer _tmp2_;
		GtkTreeIter current = {0};
		GtkListStore* _tmp3_;
		GtkTreeIter _tmp4_ = {0};
		GtkListStore* _tmp5_;
		GtkTreeIter _tmp6_;
		GnomePieIconSelectWindowListEntry* _tmp7_;
		const gchar* _tmp8_;
		GnomePieIconSelectWindowListEntry* _tmp9_;
		GdkPixbuf* _tmp10_;
		_tmp0_ = self->priv->load_queue;
		if (!(g_async_queue_length (_tmp0_) > 0)) {
			break;
		}
		_tmp1_ = self->priv->load_queue;
		_tmp2_ = g_async_queue_pop (_tmp1_);
		new_entry = (GnomePieIconSelectWindowListEntry*) _tmp2_;
		_tmp3_ = gnome_pie_icon_select_window_icon_list;
		gtk_list_store_append (_tmp3_, &_tmp4_);
		current = _tmp4_;
		_tmp5_ = gnome_pie_icon_select_window_icon_list;
		_tmp6_ = current;
		_tmp7_ = new_entry;
		_tmp8_ = _tmp7_->name;
		_tmp9_ = new_entry;
		_tmp10_ = _tmp9_->pixbuf;
		gtk_list_store_set (_tmp5_, &_tmp6_, 0, _tmp8_, 1, _tmp10_, -1);
		_gnome_pie_icon_select_window_list_entry_unref0 (new_entry);
	}
	if (!gnome_pie_icon_select_window_loading) {
		GtkListStore* _tmp11_;
		_tmp11_ = gnome_pie_icon_select_window_icon_list;
		gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp11_, 0, GTK_SORT_ASCENDING);
	}
	result = gnome_pie_icon_select_window_loading;
	return result;
}

static gboolean
____lambda42__gsource_func (gpointer self)
{
	gboolean result;
	result = ___lambda42_ ((GnomePieIconSelectWindow*) self);
	return result;
}

static void
gnome_pie_icon_select_window_load_icons (GnomePieIconSelectWindow* self)
{
	g_return_if_fail (self != NULL);
	if (!gnome_pie_icon_select_window_loading) {
		GtkListStore* _tmp0_;
		GtkSpinner* _tmp1_;
		GtkListStore* _tmp3_;
		gnome_pie_icon_select_window_loading = TRUE;
		_tmp0_ = gnome_pie_icon_select_window_icon_list;
		gtk_list_store_clear (_tmp0_);
		_tmp1_ = self->priv->spinner;
		if (_tmp1_ != NULL) {
			GtkSpinner* _tmp2_;
			_tmp2_ = self->priv->spinner;
			gtk_widget_set_visible ((GtkWidget*) _tmp2_, TRUE);
		}
		_tmp3_ = gnome_pie_icon_select_window_icon_list;
		gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp3_, -1, GTK_SORT_ASCENDING);
		gnome_pie_icon_select_window_load_all (self, NULL, NULL);
		g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) 200, ____lambda42__gsource_func, g_object_ref (self), g_object_unref);
	}
}

static void
gnome_pie_icon_select_window_load_all_data_free (gpointer _data)
{
	GnomePieIconSelectWindowLoadAllData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (GnomePieIconSelectWindowLoadAllData, _data_);
}

static void
gnome_pie_icon_select_window_load_all (GnomePieIconSelectWindow* self,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_)
{
	GnomePieIconSelectWindowLoadAllData* _data_;
	GnomePieIconSelectWindow* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (GnomePieIconSelectWindowLoadAllData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, gnome_pie_icon_select_window_load_all_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	gnome_pie_icon_select_window_load_all_co (_data_);
}

static void
gnome_pie_icon_select_window_load_all_finish (GnomePieIconSelectWindow* self,
                                              GAsyncResult* _res_)
{
	GnomePieIconSelectWindowLoadAllData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static gboolean
_gnome_pie_icon_select_window_load_all_co_gsource_func (gpointer self)
{
	gboolean result;
	result = gnome_pie_icon_select_window_load_all_co (self);
	return result;
}

static gpointer
_gnome_pie_icon_select_window_list_entry_ref0 (gpointer self)
{
	return self ? gnome_pie_icon_select_window_list_entry_ref (self) : NULL;
}

static void
_g_free0_ (gpointer var)
{
	var = (g_free (var), NULL);
}

static inline void
_g_list_free__g_free0_ (GList* self)
{
	g_list_free_full (self, (GDestroyNotify) _g_free0_);
}

static gboolean
gnome_pie_icon_select_window_load_all_co (GnomePieIconSelectWindowLoadAllData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gtk_icon_theme_get_default ();
	_data_->_tmp1_ = _g_object_ref0 (_data_->_tmp0_);
	_data_->icon_theme = _data_->_tmp1_;
	_data_->_tmp2_ = _data_->icon_theme;
	_data_->_tmp3_ = gtk_icon_theme_list_icons (_data_->_tmp2_, NULL);
	{
		_data_->icon_collection = _data_->_tmp3_;
		for (_data_->icon_it = _data_->icon_collection; _data_->icon_it != NULL; _data_->icon_it = _data_->icon_it->next) {
			_data_->_tmp4_ = g_strdup ((const gchar*) _data_->icon_it->data);
			_data_->icon = _data_->_tmp4_;
			{
				g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, _gnome_pie_icon_select_window_load_all_co_gsource_func, _data_, NULL);
				_data_->_state_ = 1;
				return FALSE;
				_state_1:
				;
				{
					_data_->_tmp5_ = gnome_pie_icon_select_window_list_entry_new ();
					_data_->new_entry = _data_->_tmp5_;
					_data_->_tmp6_ = _data_->new_entry;
					_data_->_tmp7_ = _data_->icon;
					_data_->_tmp8_ = g_strdup (_data_->_tmp7_);
					_g_free0 (_data_->_tmp6_->name);
					_data_->_tmp6_->name = _data_->_tmp8_;
					_data_->_tmp10_ = _data_->icon_theme;
					_data_->_tmp11_ = _data_->icon;
					_data_->_tmp12_ = gtk_icon_theme_load_icon (_data_->_tmp10_, _data_->_tmp11_, 32, GTK_ICON_LOOKUP_FORCE_SIZE, &_data_->_inner_error0_);
					_data_->_tmp9_ = _data_->_tmp12_;
					if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
						_gnome_pie_icon_select_window_list_entry_unref0 (_data_->new_entry);
						goto __catch0_g_error;
					}
					_data_->_tmp13_ = _data_->new_entry;
					_data_->_tmp14_ = _data_->_tmp9_;
					_data_->_tmp9_ = NULL;
					_g_object_unref0 (_data_->_tmp13_->pixbuf);
					_data_->_tmp13_->pixbuf = _data_->_tmp14_;
					_data_->_tmp15_ = _data_->self->priv->load_queue;
					_data_->_tmp16_ = _data_->new_entry;
					_data_->_tmp17_ = _gnome_pie_icon_select_window_list_entry_ref0 (_data_->_tmp16_);
					g_async_queue_push (_data_->_tmp15_, _data_->_tmp17_);
					_g_object_unref0 (_data_->_tmp9_);
					_gnome_pie_icon_select_window_list_entry_unref0 (_data_->new_entry);
				}
				goto __finally0;
				__catch0_g_error:
				{
					g_clear_error (&_data_->_inner_error0_);
					_data_->_tmp18_ = _data_->icon;
					_data_->_tmp19_ = g_strconcat ("Failed to load image ", _data_->_tmp18_, NULL);
					_data_->_tmp20_ = _data_->_tmp19_;
					g_warning ("iconSelectWindow.vala:377: %s", _data_->_tmp20_);
					_g_free0 (_data_->_tmp20_);
				}
				__finally0:
				if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
					_g_free0 (_data_->icon);
					(_data_->icon_collection == NULL) ? NULL : (_data_->icon_collection = (_g_list_free__g_free0_ (_data_->icon_collection), NULL));
					_g_object_unref0 (_data_->icon_theme);
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
					g_clear_error (&_data_->_inner_error0_);
					g_object_unref (_data_->_async_result);
					return FALSE;
				}
				_g_free0 (_data_->icon);
			}
		}
		(_data_->icon_collection == NULL) ? NULL : (_data_->icon_collection = (_g_list_free__g_free0_ (_data_->icon_collection), NULL));
	}
	gnome_pie_icon_select_window_loading = FALSE;
	_data_->_tmp21_ = _data_->self->priv->spinner;
	if (_data_->_tmp21_ != NULL) {
		_data_->_tmp22_ = _data_->self->priv->spinner;
		gtk_widget_set_visible ((GtkWidget*) _data_->_tmp22_, FALSE);
	}
	_g_object_unref0 (_data_->icon_theme);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static GnomePieIconSelectWindowListEntry*
gnome_pie_icon_select_window_list_entry_construct (GType object_type)
{
	GnomePieIconSelectWindowListEntry* self = NULL;
	self = (GnomePieIconSelectWindowListEntry*) g_type_create_instance (object_type);
	return self;
}

static GnomePieIconSelectWindowListEntry*
gnome_pie_icon_select_window_list_entry_new (void)
{
	return gnome_pie_icon_select_window_list_entry_construct (GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY);
}

static void
gnome_pie_icon_select_window_value_list_entry_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
gnome_pie_icon_select_window_value_list_entry_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		gnome_pie_icon_select_window_list_entry_unref (value->data[0].v_pointer);
	}
}

static void
gnome_pie_icon_select_window_value_list_entry_copy_value (const GValue* src_value,
                                                          GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = gnome_pie_icon_select_window_list_entry_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
gnome_pie_icon_select_window_value_list_entry_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
gnome_pie_icon_select_window_value_list_entry_collect_value (GValue* value,
                                                             guint n_collect_values,
                                                             GTypeCValue* collect_values,
                                                             guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		GnomePieIconSelectWindowListEntry * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = gnome_pie_icon_select_window_list_entry_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
gnome_pie_icon_select_window_value_list_entry_lcopy_value (const GValue* value,
                                                           guint n_collect_values,
                                                           GTypeCValue* collect_values,
                                                           guint collect_flags)
{
	GnomePieIconSelectWindowListEntry ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = gnome_pie_icon_select_window_list_entry_ref (value->data[0].v_pointer);
	}
	return NULL;
}

static GParamSpec*
gnome_pie_icon_select_window_param_spec_list_entry (const gchar* name,
                                                    const gchar* nick,
                                                    const gchar* blurb,
                                                    GType object_type,
                                                    GParamFlags flags)
{
	GnomePieIconSelectWindowParamSpecListEntry* spec;
	g_return_val_if_fail (g_type_is_a (object_type, GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

static gpointer
gnome_pie_icon_select_window_value_get_list_entry (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY), NULL);
	return value->data[0].v_pointer;
}

static void
gnome_pie_icon_select_window_value_set_list_entry (GValue* value,
                                                   gpointer v_object)
{
	GnomePieIconSelectWindowListEntry * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		gnome_pie_icon_select_window_list_entry_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gnome_pie_icon_select_window_list_entry_unref (old);
	}
}

static void
gnome_pie_icon_select_window_value_take_list_entry (GValue* value,
                                                    gpointer v_object)
{
	GnomePieIconSelectWindowListEntry * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gnome_pie_icon_select_window_list_entry_unref (old);
	}
}

static void
gnome_pie_icon_select_window_list_entry_class_init (GnomePieIconSelectWindowListEntryClass * klass,
                                                    gpointer klass_data)
{
	gnome_pie_icon_select_window_list_entry_parent_class = g_type_class_peek_parent (klass);
	((GnomePieIconSelectWindowListEntryClass *) klass)->finalize = gnome_pie_icon_select_window_list_entry_finalize;
}

static void
gnome_pie_icon_select_window_list_entry_instance_init (GnomePieIconSelectWindowListEntry * self,
                                                       gpointer klass)
{
	self->ref_count = 1;
}

static void
gnome_pie_icon_select_window_list_entry_finalize (GnomePieIconSelectWindowListEntry * obj)
{
	GnomePieIconSelectWindowListEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_ICON_SELECT_WINDOW_TYPE_LIST_ENTRY, GnomePieIconSelectWindowListEntry);
	g_signal_handlers_destroy (self);
	_g_free0 (self->name);
	_g_object_unref0 (self->pixbuf);
}

static GType
gnome_pie_icon_select_window_list_entry_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { gnome_pie_icon_select_window_value_list_entry_init, gnome_pie_icon_select_window_value_list_entry_free_value, gnome_pie_icon_select_window_value_list_entry_copy_value, gnome_pie_icon_select_window_value_list_entry_peek_pointer, "p", gnome_pie_icon_select_window_value_list_entry_collect_value, "p", gnome_pie_icon_select_window_value_list_entry_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieIconSelectWindowListEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_icon_select_window_list_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieIconSelectWindowListEntry), 0, (GInstanceInitFunc) gnome_pie_icon_select_window_list_entry_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType gnome_pie_icon_select_window_list_entry_type_id;
	gnome_pie_icon_select_window_list_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "GnomePieIconSelectWindowListEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
	return gnome_pie_icon_select_window_list_entry_type_id;
}

static GType
gnome_pie_icon_select_window_list_entry_get_type (void)
{
	static volatile gsize gnome_pie_icon_select_window_list_entry_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_icon_select_window_list_entry_type_id__once)) {
		GType gnome_pie_icon_select_window_list_entry_type_id;
		gnome_pie_icon_select_window_list_entry_type_id = gnome_pie_icon_select_window_list_entry_get_type_once ();
		g_once_init_leave (&gnome_pie_icon_select_window_list_entry_type_id__once, gnome_pie_icon_select_window_list_entry_type_id);
	}
	return gnome_pie_icon_select_window_list_entry_type_id__once;
}

static gpointer
gnome_pie_icon_select_window_list_entry_ref (gpointer instance)
{
	GnomePieIconSelectWindowListEntry * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

static void
gnome_pie_icon_select_window_list_entry_unref (gpointer instance)
{
	GnomePieIconSelectWindowListEntry * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		GNOME_PIE_ICON_SELECT_WINDOW_LIST_ENTRY_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

static void
gnome_pie_icon_select_window_class_init (GnomePieIconSelectWindowClass * klass,
                                         gpointer klass_data)
{
	gnome_pie_icon_select_window_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GnomePieIconSelectWindow_private_offset);
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_icon_select_window_finalize;
	gnome_pie_icon_select_window_signals[GNOME_PIE_ICON_SELECT_WINDOW_ON_OK_SIGNAL] = g_signal_new ("on-ok", GNOME_PIE_TYPE_ICON_SELECT_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
}

static void
gnome_pie_icon_select_window_instance_init (GnomePieIconSelectWindow * self,
                                            gpointer klass)
{
	gchar* _tmp0_;
	self->priv = gnome_pie_icon_select_window_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->active_icon = _tmp0_;
	self->priv->icon_list_filtered = NULL;
	self->priv->icon_view = NULL;
	self->priv->spinner = NULL;
	self->priv->file_chooser = NULL;
	self->priv->tabs = NULL;
	self->priv->window = NULL;
}

static void
gnome_pie_icon_select_window_finalize (GObject * obj)
{
	GnomePieIconSelectWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_ICON_SELECT_WINDOW, GnomePieIconSelectWindow);
	_g_free0 (self->priv->active_icon);
	_g_object_unref0 (self->priv->icon_list_filtered);
	_g_object_unref0 (self->priv->icon_view);
	_g_object_unref0 (self->priv->spinner);
	_g_object_unref0 (self->priv->file_chooser);
	_g_object_unref0 (self->priv->tabs);
	_g_object_unref0 (self->priv->window);
	_g_async_queue_unref0 (self->priv->load_queue);
	G_OBJECT_CLASS (gnome_pie_icon_select_window_parent_class)->finalize (obj);
}

static GType
gnome_pie_icon_select_window_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieIconSelectWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_icon_select_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieIconSelectWindow), 0, (GInstanceInitFunc) gnome_pie_icon_select_window_instance_init, NULL };
	GType gnome_pie_icon_select_window_type_id;
	gnome_pie_icon_select_window_type_id = g_type_register_static (G_TYPE_OBJECT, "GnomePieIconSelectWindow", &g_define_type_info, 0);
	GnomePieIconSelectWindow_private_offset = g_type_add_instance_private (gnome_pie_icon_select_window_type_id, sizeof (GnomePieIconSelectWindowPrivate));
	return gnome_pie_icon_select_window_type_id;
}

GType
gnome_pie_icon_select_window_get_type (void)
{
	static volatile gsize gnome_pie_icon_select_window_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_icon_select_window_type_id__once)) {
		GType gnome_pie_icon_select_window_type_id;
		gnome_pie_icon_select_window_type_id = gnome_pie_icon_select_window_get_type_once ();
		g_once_init_leave (&gnome_pie_icon_select_window_type_id__once, gnome_pie_icon_select_window_type_id);
	}
	return gnome_pie_icon_select_window_type_id__once;
}

