/* aboutWindow.c generated by valac 0.56.19, the Vala compiler
 * generated from aboutWindow.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_ABOUT_WINDOW (gnome_pie_about_window_get_type ())
#define GNOME_PIE_ABOUT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ABOUT_WINDOW, GnomePieAboutWindow))
#define GNOME_PIE_ABOUT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ABOUT_WINDOW, GnomePieAboutWindowClass))
#define GNOME_PIE_IS_ABOUT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ABOUT_WINDOW))
#define GNOME_PIE_IS_ABOUT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ABOUT_WINDOW))
#define GNOME_PIE_ABOUT_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ABOUT_WINDOW, GnomePieAboutWindowClass))

typedef struct _GnomePieAboutWindow GnomePieAboutWindow;
typedef struct _GnomePieAboutWindowClass GnomePieAboutWindowClass;
typedef struct _GnomePieAboutWindowPrivate GnomePieAboutWindowPrivate;
enum  {
	GNOME_PIE_ABOUT_WINDOW_0_PROPERTY,
	GNOME_PIE_ABOUT_WINDOW_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_about_window_properties[GNOME_PIE_ABOUT_WINDOW_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

struct _GnomePieAboutWindow {
	GtkAboutDialog parent_instance;
	GnomePieAboutWindowPrivate * priv;
};

struct _GnomePieAboutWindowClass {
	GtkAboutDialogClass parent_class;
};

static gpointer gnome_pie_about_window_parent_class = NULL;
VALA_EXTERN gchar* gnome_pie_daemon_version;

VALA_EXTERN GType gnome_pie_about_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAboutWindow, g_object_unref)
VALA_EXTERN GnomePieAboutWindow* gnome_pie_about_window_new (void);
VALA_EXTERN GnomePieAboutWindow* gnome_pie_about_window_construct (GType object_type);
static gint __lambda96_ (const gchar* a,
                  const gchar* b);
static gint ___lambda96__gcompare_func (gconstpointer a,
                                 gconstpointer b);
static void _g_free0_ (gpointer var);
static inline void _g_list_free__g_free0_ (GList* self);
static GType gnome_pie_about_window_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static gint
__lambda96_ (const gchar* a,
             const gchar* b)
{
	gint result;
	g_return_val_if_fail (a != NULL, -1);
	g_return_val_if_fail (b != NULL, -1);
	result = g_ascii_strcasecmp (a, b);
	return result;
}

static gint
___lambda96__gcompare_func (gconstpointer a,
                            gconstpointer b)
{
	gint result;
	result = __lambda96_ ((const gchar*) a, (const gchar*) b);
	return result;
}

static void
_g_free0_ (gpointer var)
{
	var = (g_free (var), NULL);
}

static inline void
_g_list_free__g_free0_ (GList* self)
{
	g_list_free_full (self, (GDestroyNotify) _g_free0_);
}

GnomePieAboutWindow*
gnome_pie_about_window_construct (GType object_type)
{
	GnomePieAboutWindow * self = NULL;
	gchar** devs = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gint devs_length1;
	gint _devs_size_;
	gchar** artists = NULL;
	gchar* _tmp7_;
	gchar** _tmp8_;
	gint artists_length1;
	gint _artists_size_;
	gchar** translators = NULL;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	gchar** _tmp24_;
	gint translators_length1;
	gint _translators_size_;
	GList* translator_list = NULL;
	gchar** _tmp25_;
	gint _tmp25__length1;
	gchar* translator_string = NULL;
	gchar* _tmp29_;
	GList* _tmp30_;
	gchar** _tmp37_;
	gint _tmp37__length1;
	gchar** _tmp38_;
	gint _tmp38__length1;
	const gchar* _tmp39_;
	const gchar* _tmp40_;
	_tmp0_ = g_strdup ("Simon Schneegans <code@simonschneegans.de>");
	_tmp1_ = g_strdup ("Gabriel Dubatti <gdubatti@gmail.com>");
	_tmp2_ = g_strdup ("Glitsj16 <glitsj16@riseup.net>");
	_tmp3_ = g_strdup ("Francesco Piccinno <stack.box@gmail.com>");
	_tmp4_ = g_strdup ("György Balló <ballogyor@gmail.com>");
	_tmp5_ = g_strdup ("Tiago de Oliveira Corrêa <tcorreabr@gmail.com>");
	_tmp6_ = g_new0 (gchar*, 6 + 1);
	_tmp6_[0] = _tmp0_;
	_tmp6_[1] = _tmp1_;
	_tmp6_[2] = _tmp2_;
	_tmp6_[3] = _tmp3_;
	_tmp6_[4] = _tmp4_;
	_tmp6_[5] = _tmp5_;
	devs = _tmp6_;
	devs_length1 = 6;
	_devs_size_ = devs_length1;
	_tmp7_ = g_strdup ("Simon Schneegans <code@simonschneegans.de>");
	_tmp8_ = g_new0 (gchar*, 1 + 1);
	_tmp8_[0] = _tmp7_;
	artists = _tmp8_;
	artists_length1 = 1;
	_artists_size_ = artists_length1;
	_tmp9_ = g_strdup ("Simon Schneegans <code@simonschneegans.de> (DE, EN)");
	_tmp10_ = g_strdup ("Riccardo Traverso <gr3yfox.fw@gmail.com> (IT)");
	_tmp11_ = g_strdup ("Magnun Leno <magnun@codecommunity.org> (PT-BR)");
	_tmp12_ = g_strdup ("Kim Boram <Boramism@gmail.com> (KO)");
	_tmp13_ = g_strdup ("Eduardo Anabalon <lalo1412@gmail.com> (ES)");
	_tmp14_ = g_strdup ("Moo <hazap@hotmail.com> (LT)");
	_tmp15_ = g_strdup ("Gabriel Dubatti <gdubatti@gmail.com> (ES)");
	_tmp16_ = g_strdup ("Grégoire Bellon-Gervais <greggbg@gmail.com> (FR)");
	_tmp17_ = g_strdup ("Raphaël Rochet <raphael@rri.fr> (FR)");
	_tmp18_ = g_strdup ("Alex Maxime <cad.maxime@gmail.com> (FR)");
	_tmp19_ = g_strdup ("Eugene Roskin <pams@imail.ru> (RU)");
	_tmp20_ = g_strdup ("Ashed <craysy@gmail.com> (RU)");
	_tmp21_ = g_strdup ("Ting Zhou <tzhou@haverford.edu> (ZH-CN)");
	_tmp22_ = g_strdup ("Martin Dinov <martindinov@yahoo.com> (BG)");
	_tmp23_ = g_strdup ("Heimen Stoffels <vistausss@outlook.com> (NL-NL)");
	_tmp24_ = g_new0 (gchar*, 15 + 1);
	_tmp24_[0] = _tmp9_;
	_tmp24_[1] = _tmp10_;
	_tmp24_[2] = _tmp11_;
	_tmp24_[3] = _tmp12_;
	_tmp24_[4] = _tmp13_;
	_tmp24_[5] = _tmp14_;
	_tmp24_[6] = _tmp15_;
	_tmp24_[7] = _tmp16_;
	_tmp24_[8] = _tmp17_;
	_tmp24_[9] = _tmp18_;
	_tmp24_[10] = _tmp19_;
	_tmp24_[11] = _tmp20_;
	_tmp24_[12] = _tmp21_;
	_tmp24_[13] = _tmp22_;
	_tmp24_[14] = _tmp23_;
	translators = _tmp24_;
	translators_length1 = 15;
	_translators_size_ = translators_length1;
	translator_list = NULL;
	_tmp25_ = translators;
	_tmp25__length1 = translators_length1;
	{
		gchar** translator_collection = NULL;
		gint translator_collection_length1 = 0;
		gint _translator_collection_size_ = 0;
		gint translator_it = 0;
		translator_collection = _tmp25_;
		translator_collection_length1 = _tmp25__length1;
		for (translator_it = 0; translator_it < translator_collection_length1; translator_it = translator_it + 1) {
			gchar* _tmp26_;
			gchar* translator = NULL;
			_tmp26_ = g_strdup (translator_collection[translator_it]);
			translator = _tmp26_;
			{
				const gchar* _tmp27_;
				gchar* _tmp28_;
				_tmp27_ = translator;
				_tmp28_ = g_strdup (_tmp27_);
				translator_list = g_list_append (translator_list, _tmp28_);
				_g_free0 (translator);
			}
		}
	}
	translator_list = g_list_sort (translator_list, ___lambda96__gcompare_func);
	_tmp29_ = g_strdup ("");
	translator_string = _tmp29_;
	_tmp30_ = translator_list;
	{
		GList* translator_collection = NULL;
		GList* translator_it = NULL;
		translator_collection = _tmp30_;
		for (translator_it = translator_collection; translator_it != NULL; translator_it = translator_it->next) {
			gchar* _tmp31_;
			gchar* translator = NULL;
			_tmp31_ = g_strdup ((const gchar*) translator_it->data);
			translator = _tmp31_;
			{
				const gchar* _tmp32_;
				const gchar* _tmp33_;
				gchar* _tmp34_;
				gchar* _tmp35_;
				gchar* _tmp36_;
				_tmp32_ = translator_string;
				_tmp33_ = translator;
				_tmp34_ = g_strconcat (_tmp33_, "\n", NULL);
				_tmp35_ = _tmp34_;
				_tmp36_ = g_strconcat (_tmp32_, _tmp35_, NULL);
				_g_free0 (translator_string);
				translator_string = _tmp36_;
				_g_free0 (_tmp35_);
				_g_free0 (translator);
			}
		}
	}
	_tmp37_ = artists;
	_tmp37__length1 = artists_length1;
	_tmp38_ = devs;
	_tmp38__length1 = devs_length1;
	_tmp39_ = translator_string;
	_tmp40_ = gnome_pie_daemon_version;
	self = (GnomePieAboutWindow*) g_object_new (object_type, "artists", _tmp37_, "authors", _tmp38_, "translator-credits", _tmp39_, "copyright", "Copyright 2011-2021 Simon Schneegans <code@simonschneegans.de>", "program-name", "Gnome-Pie", "logo-icon-name", "gnome-pie", "website", "http://schneegans.github.io/gnome-pie.html", "website-label", "Homepage", "version", _tmp40_, NULL);
	_g_free0 (translator_string);
	(translator_list == NULL) ? NULL : (translator_list = (_g_list_free__g_free0_ (translator_list), NULL));
	translators = (_vala_array_free (translators, translators_length1, (GDestroyNotify) g_free), NULL);
	artists = (_vala_array_free (artists, artists_length1, (GDestroyNotify) g_free), NULL);
	devs = (_vala_array_free (devs, devs_length1, (GDestroyNotify) g_free), NULL);
	return self;
}

GnomePieAboutWindow*
gnome_pie_about_window_new (void)
{
	return gnome_pie_about_window_construct (GNOME_PIE_TYPE_ABOUT_WINDOW);
}

static void
gnome_pie_about_window_class_init (GnomePieAboutWindowClass * klass,
                                   gpointer klass_data)
{
	gnome_pie_about_window_parent_class = g_type_class_peek_parent (klass);
}

static void
gnome_pie_about_window_instance_init (GnomePieAboutWindow * self,
                                      gpointer klass)
{
}

static GType
gnome_pie_about_window_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieAboutWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_about_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieAboutWindow), 0, (GInstanceInitFunc) gnome_pie_about_window_instance_init, NULL };
	GType gnome_pie_about_window_type_id;
	gnome_pie_about_window_type_id = g_type_register_static (gtk_about_dialog_get_type (), "GnomePieAboutWindow", &g_define_type_info, 0);
	return gnome_pie_about_window_type_id;
}

GType
gnome_pie_about_window_get_type (void)
{
	static volatile gsize gnome_pie_about_window_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_about_window_type_id__once)) {
		GType gnome_pie_about_window_type_id;
		gnome_pie_about_window_type_id = gnome_pie_about_window_get_type_once ();
		g_once_init_leave (&gnome_pie_about_window_type_id__once, gnome_pie_about_window_type_id);
	}
	return gnome_pie_about_window_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

