/* commandComboList.c generated by valac 0.56.19, the Vala compiler
 * generated from commandComboList.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_COMMAND_COMBO_LIST (gnome_pie_command_combo_list_get_type ())
#define GNOME_PIE_COMMAND_COMBO_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboList))
#define GNOME_PIE_COMMAND_COMBO_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboListClass))
#define GNOME_PIE_IS_COMMAND_COMBO_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_COMMAND_COMBO_LIST))
#define GNOME_PIE_IS_COMMAND_COMBO_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_COMMAND_COMBO_LIST))
#define GNOME_PIE_COMMAND_COMBO_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboListClass))

typedef struct _GnomePieCommandComboList GnomePieCommandComboList;
typedef struct _GnomePieCommandComboListClass GnomePieCommandComboListClass;
typedef struct _GnomePieCommandComboListPrivate GnomePieCommandComboListPrivate;
enum  {
	GNOME_PIE_COMMAND_COMBO_LIST_0_PROPERTY,
	GNOME_PIE_COMMAND_COMBO_LIST_TEXT_PROPERTY,
	GNOME_PIE_COMMAND_COMBO_LIST_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_command_combo_list_properties[GNOME_PIE_COMMAND_COMBO_LIST_NUM_PROPERTIES];
typedef enum  {
	GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_ICON,
	GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_NAME,
	GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_COMMAND
} GnomePieCommandComboListDataPos;

#define GNOME_PIE_COMMAND_COMBO_LIST_TYPE_DATA_POS (gnome_pie_command_combo_list_data_pos_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
enum  {
	GNOME_PIE_COMMAND_COMBO_LIST_ON_SELECT_SIGNAL,
	GNOME_PIE_COMMAND_COMBO_LIST_NUM_SIGNALS
};
static guint gnome_pie_command_combo_list_signals[GNOME_PIE_COMMAND_COMBO_LIST_NUM_SIGNALS] = {0};

struct _GnomePieCommandComboList {
	GtkComboBox parent_instance;
	GnomePieCommandComboListPrivate * priv;
};

struct _GnomePieCommandComboListClass {
	GtkComboBoxClass parent_class;
};

struct _GnomePieCommandComboListPrivate {
	GtkListStore* data;
};

static gint GnomePieCommandComboList_private_offset;
static gpointer gnome_pie_command_combo_list_parent_class = NULL;

VALA_EXTERN GType gnome_pie_command_combo_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieCommandComboList, g_object_unref)
static GType gnome_pie_command_combo_list_data_pos_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
VALA_EXTERN GnomePieCommandComboList* gnome_pie_command_combo_list_new (void);
VALA_EXTERN GnomePieCommandComboList* gnome_pie_command_combo_list_construct (GType object_type);
static void __lambda51_ (GnomePieCommandComboList* self);
static void ___lambda51__gtk_combo_box_changed (GtkComboBox* _sender,
                                         gpointer self);
VALA_EXTERN void gnome_pie_command_combo_list_reload (GnomePieCommandComboList* self);
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
VALA_EXTERN const gchar* gnome_pie_command_combo_list_get_text (GnomePieCommandComboList* self);
VALA_EXTERN void gnome_pie_command_combo_list_set_text (GnomePieCommandComboList* self,
                                            const gchar* value);
static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING (GClosure * closure,
                                                         GValue * return_value,
                                                         guint n_param_values,
                                                         const GValue * param_values,
                                                         gpointer invocation_hint,
                                                         gpointer marshal_data);
static void gnome_pie_command_combo_list_finalize (GObject * obj);
static GType gnome_pie_command_combo_list_get_type_once (void);
static void _vala_gnome_pie_command_combo_list_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec);
static void _vala_gnome_pie_command_combo_list_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec);

static inline gpointer
gnome_pie_command_combo_list_get_instance_private (GnomePieCommandComboList* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePieCommandComboList_private_offset);
}

static GType
gnome_pie_command_combo_list_data_pos_get_type_once (void)
{
	static const GEnumValue values[] = {{GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_ICON, "GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_ICON", "icon"}, {GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_NAME, "GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_NAME", "name"}, {GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_COMMAND, "GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_COMMAND", "command"}, {0, NULL, NULL}};
	GType gnome_pie_command_combo_list_data_pos_type_id;
	gnome_pie_command_combo_list_data_pos_type_id = g_enum_register_static ("GnomePieCommandComboListDataPos", values);
	return gnome_pie_command_combo_list_data_pos_type_id;
}

static GType
gnome_pie_command_combo_list_data_pos_get_type (void)
{
	static volatile gsize gnome_pie_command_combo_list_data_pos_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_command_combo_list_data_pos_type_id__once)) {
		GType gnome_pie_command_combo_list_data_pos_type_id;
		gnome_pie_command_combo_list_data_pos_type_id = gnome_pie_command_combo_list_data_pos_get_type_once ();
		g_once_init_leave (&gnome_pie_command_combo_list_data_pos_type_id__once, gnome_pie_command_combo_list_data_pos_type_id);
	}
	return gnome_pie_command_combo_list_data_pos_type_id__once;
}

static void
__lambda51_ (GnomePieCommandComboList* self)
{
	GtkTreeIter active = {0};
	GtkTreeIter _tmp0_ = {0};
	gboolean _tmp1_;
	_tmp1_ = gtk_combo_box_get_active_iter ((GtkComboBox*) self, &_tmp0_);
	active = _tmp0_;
	if (_tmp1_) {
		gchar* name = NULL;
		gchar* _tmp2_;
		gchar* command = NULL;
		gchar* _tmp3_;
		gchar* icon = NULL;
		gchar* _tmp4_;
		GtkListStore* _tmp5_;
		GtkTreeIter _tmp6_;
		gchar* _tmp7_ = NULL;
		GtkListStore* _tmp8_;
		GtkTreeIter _tmp9_;
		gchar* _tmp10_ = NULL;
		GtkListStore* _tmp11_;
		GtkTreeIter _tmp12_;
		gchar* _tmp13_ = NULL;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		_tmp2_ = g_strdup ("");
		name = _tmp2_;
		_tmp3_ = g_strdup ("");
		command = _tmp3_;
		_tmp4_ = g_strdup ("");
		icon = _tmp4_;
		_tmp5_ = self->priv->data;
		_tmp6_ = active;
		gtk_tree_model_get ((GtkTreeModel*) _tmp5_, &_tmp6_, GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_NAME, &_tmp7_, -1);
		_g_free0 (name);
		name = _tmp7_;
		_tmp8_ = self->priv->data;
		_tmp9_ = active;
		gtk_tree_model_get ((GtkTreeModel*) _tmp8_, &_tmp9_, GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_COMMAND, &_tmp10_, -1);
		_g_free0 (command);
		command = _tmp10_;
		_tmp11_ = self->priv->data;
		_tmp12_ = active;
		gtk_tree_model_get ((GtkTreeModel*) _tmp11_, &_tmp12_, GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_ICON, &_tmp13_, -1);
		_g_free0 (icon);
		icon = _tmp13_;
		_tmp14_ = name;
		_tmp15_ = command;
		_tmp16_ = icon;
		g_signal_emit (self, gnome_pie_command_combo_list_signals[GNOME_PIE_COMMAND_COMBO_LIST_ON_SELECT_SIGNAL], 0, _tmp14_, _tmp15_, _tmp16_);
		_g_free0 (icon);
		_g_free0 (command);
		_g_free0 (name);
	}
}

static void
___lambda51__gtk_combo_box_changed (GtkComboBox* _sender,
                                    gpointer self)
{
	__lambda51_ ((GnomePieCommandComboList*) self);
}

GnomePieCommandComboList*
gnome_pie_command_combo_list_construct (GType object_type)
{
	GnomePieCommandComboList * self = NULL;
	GtkListStore* _tmp0_;
	GtkListStore* _tmp1_;
	GtkListStore* _tmp2_;
	GList* _tmp3_;
	GList* _tmp4_;
	gconstpointer _tmp5_;
	GtkCellRendererPixbuf* icon_render = NULL;
	GtkCellRendererPixbuf* _tmp6_;
	GtkCellRendererText* name_render = NULL;
	GtkCellRendererText* _tmp7_;
	self = (GnomePieCommandComboList*) g_object_new (object_type, "has-entry", TRUE, NULL);
	_tmp0_ = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, -1);
	_g_object_unref0 (self->priv->data);
	self->priv->data = _tmp0_;
	_tmp1_ = self->priv->data;
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp1_, 1, GTK_SORT_ASCENDING);
	gtk_combo_box_set_entry_text_column ((GtkComboBox*) self, 2);
	gtk_combo_box_set_id_column ((GtkComboBox*) self, 2);
	_tmp2_ = self->priv->data;
	gtk_combo_box_set_model (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_combo_box_get_type (), GtkComboBox), (GtkTreeModel*) _tmp2_);
	_tmp3_ = gtk_cell_layout_get_cells ((GtkCellLayout*) self);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_list_nth_data (_tmp4_, (guint) 0);
	gtk_cell_renderer_set_visible ((GtkCellRenderer*) _tmp5_, FALSE);
	(_tmp4_ == NULL) ? NULL : (_tmp4_ = (g_list_free (_tmp4_), NULL));
	_tmp6_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
	g_object_ref_sink (_tmp6_);
	icon_render = _tmp6_;
	g_object_set ((GtkCellRenderer*) icon_render, "xpad", (guint) 4, NULL);
	gtk_cell_layout_pack_start ((GtkCellLayout*) self, (GtkCellRenderer*) icon_render, FALSE);
	_tmp7_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
	g_object_ref_sink (_tmp7_);
	name_render = _tmp7_;
	gtk_cell_layout_pack_start ((GtkCellLayout*) self, (GtkCellRenderer*) name_render, TRUE);
	gtk_cell_layout_add_attribute ((GtkCellLayout*) self, (GtkCellRenderer*) icon_render, "icon_name", (gint) GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_ICON);
	gtk_cell_layout_add_attribute ((GtkCellLayout*) self, (GtkCellRenderer*) name_render, "text", (gint) GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_NAME);
	g_signal_connect_object ((GtkComboBox*) self, "changed", (GCallback) ___lambda51__gtk_combo_box_changed, self, 0);
	gnome_pie_command_combo_list_reload (self);
	_g_object_unref0 (name_render);
	_g_object_unref0 (icon_render);
	return self;
}

GnomePieCommandComboList*
gnome_pie_command_combo_list_new (void)
{
	return gnome_pie_command_combo_list_construct (GNOME_PIE_TYPE_COMMAND_COMBO_LIST);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_g_object_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}

static inline void
_g_list_free__g_object_unref0_ (GList* self)
{
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
}

void
gnome_pie_command_combo_list_reload (GnomePieCommandComboList* self)
{
	GList* apps = NULL;
	GList* _tmp0_;
	GList* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_app_info_get_all ();
	apps = _tmp0_;
	_tmp1_ = apps;
	{
		GList* app_collection = NULL;
		GList* app_it = NULL;
		app_collection = _tmp1_;
		for (app_it = app_collection; app_it != NULL; app_it = app_it->next) {
			GAppInfo* _tmp2_;
			GAppInfo* app = NULL;
			_tmp2_ = _g_object_ref0 ((GAppInfo*) app_it->data);
			app = _tmp2_;
			{
				GAppInfo* _tmp3_;
				_tmp3_ = app;
				if (g_app_info_should_show (_tmp3_)) {
					GtkTreeIter last = {0};
					gchar* icon_name = NULL;
					gchar* _tmp4_;
					GIcon* icon = NULL;
					GAppInfo* _tmp5_;
					GIcon* _tmp6_;
					GIcon* _tmp7_;
					GIcon* _tmp8_;
					GtkListStore* _tmp11_;
					GtkTreeIter _tmp12_ = {0};
					GtkListStore* _tmp13_;
					GtkTreeIter _tmp14_;
					const gchar* _tmp15_;
					GAppInfo* _tmp16_;
					const gchar* _tmp17_;
					GAppInfo* _tmp18_;
					const gchar* _tmp19_;
					_tmp4_ = g_strdup ("application-x-executable");
					icon_name = _tmp4_;
					_tmp5_ = app;
					_tmp6_ = g_app_info_get_icon (_tmp5_);
					_tmp7_ = _g_object_ref0 (_tmp6_);
					icon = _tmp7_;
					_tmp8_ = icon;
					if (_tmp8_ != NULL) {
						GIcon* _tmp9_;
						gchar* _tmp10_;
						_tmp9_ = icon;
						_tmp10_ = g_icon_to_string (_tmp9_);
						_g_free0 (icon_name);
						icon_name = _tmp10_;
					}
					_tmp11_ = self->priv->data;
					gtk_list_store_append (_tmp11_, &_tmp12_);
					last = _tmp12_;
					_tmp13_ = self->priv->data;
					_tmp14_ = last;
					_tmp15_ = icon_name;
					_tmp16_ = app;
					_tmp17_ = g_app_info_get_display_name (_tmp16_);
					_tmp18_ = app;
					_tmp19_ = g_app_info_get_commandline (_tmp18_);
					gtk_list_store_set (_tmp13_, &_tmp14_, GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_ICON, _tmp15_, GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_NAME, _tmp17_, GNOME_PIE_COMMAND_COMBO_LIST_DATA_POS_COMMAND, _tmp19_, -1);
					_g_object_unref0 (icon);
					_g_free0 (icon_name);
				}
				_g_object_unref0 (app);
			}
		}
	}
	(apps == NULL) ? NULL : (apps = (_g_list_free__g_object_unref0_ (apps), NULL));
}

const gchar*
gnome_pie_command_combo_list_get_text (GnomePieCommandComboList* self)
{
	const gchar* result;
	GtkWidget* _tmp0_;
	const gchar* _tmp1_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = gtk_bin_get_child ((GtkBin*) self);
	_tmp1_ = gtk_entry_get_text (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp0_) : NULL);
	result = _tmp1_;
	return result;
}

void
gnome_pie_command_combo_list_set_text (GnomePieCommandComboList* self,
                                       const gchar* value)
{
	GtkWidget* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = gtk_bin_get_child ((GtkBin*) self);
	gtk_entry_set_text (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp0_) : NULL, value);
	g_object_notify_by_pspec ((GObject *) self, gnome_pie_command_combo_list_properties[GNOME_PIE_COMMAND_COMBO_LIST_TEXT_PROPERTY]);
}

static void
g_cclosure_user_marshal_VOID__STRING_STRING_STRING (GClosure * closure,
                                                    GValue * return_value,
                                                    guint n_param_values,
                                                    const GValue * param_values,
                                                    gpointer invocation_hint,
                                                    gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING) (gpointer data1, const char* arg_1, const char* arg_2, const char* arg_3, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 4);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_string (param_values + 3), data2);
}

static void
gnome_pie_command_combo_list_class_init (GnomePieCommandComboListClass * klass,
                                         gpointer klass_data)
{
	gnome_pie_command_combo_list_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GnomePieCommandComboList_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gnome_pie_command_combo_list_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gnome_pie_command_combo_list_set_property;
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_command_combo_list_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_COMMAND_COMBO_LIST_TEXT_PROPERTY, gnome_pie_command_combo_list_properties[GNOME_PIE_COMMAND_COMBO_LIST_TEXT_PROPERTY] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	gnome_pie_command_combo_list_signals[GNOME_PIE_COMMAND_COMBO_LIST_ON_SELECT_SIGNAL] = g_signal_new ("on-select", GNOME_PIE_TYPE_COMMAND_COMBO_LIST, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_STRING, G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
}

static void
gnome_pie_command_combo_list_instance_init (GnomePieCommandComboList * self,
                                            gpointer klass)
{
	self->priv = gnome_pie_command_combo_list_get_instance_private (self);
}

static void
gnome_pie_command_combo_list_finalize (GObject * obj)
{
	GnomePieCommandComboList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboList);
	_g_object_unref0 (self->priv->data);
	G_OBJECT_CLASS (gnome_pie_command_combo_list_parent_class)->finalize (obj);
}

static GType
gnome_pie_command_combo_list_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieCommandComboListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_command_combo_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieCommandComboList), 0, (GInstanceInitFunc) gnome_pie_command_combo_list_instance_init, NULL };
	GType gnome_pie_command_combo_list_type_id;
	gnome_pie_command_combo_list_type_id = g_type_register_static (gtk_combo_box_get_type (), "GnomePieCommandComboList", &g_define_type_info, 0);
	GnomePieCommandComboList_private_offset = g_type_add_instance_private (gnome_pie_command_combo_list_type_id, sizeof (GnomePieCommandComboListPrivate));
	return gnome_pie_command_combo_list_type_id;
}

GType
gnome_pie_command_combo_list_get_type (void)
{
	static volatile gsize gnome_pie_command_combo_list_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_command_combo_list_type_id__once)) {
		GType gnome_pie_command_combo_list_type_id;
		gnome_pie_command_combo_list_type_id = gnome_pie_command_combo_list_get_type_once ();
		g_once_init_leave (&gnome_pie_command_combo_list_type_id__once, gnome_pie_command_combo_list_type_id);
	}
	return gnome_pie_command_combo_list_type_id__once;
}

static void
_vala_gnome_pie_command_combo_list_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec)
{
	GnomePieCommandComboList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboList);
	switch (property_id) {
		case GNOME_PIE_COMMAND_COMBO_LIST_TEXT_PROPERTY:
		g_value_set_string (value, gnome_pie_command_combo_list_get_text (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gnome_pie_command_combo_list_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec)
{
	GnomePieCommandComboList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboList);
	switch (property_id) {
		case GNOME_PIE_COMMAND_COMBO_LIST_TEXT_PROPERTY:
		gnome_pie_command_combo_list_set_text (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

