/* actionGroup.c generated by valac 0.56.19, the Vala compiler
 * generated from actionGroup.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <libxml/xmlwriter.h>
#include <libxml/tree.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_ACTION_GROUP (gnome_pie_action_group_get_type ())
#define GNOME_PIE_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup))
#define GNOME_PIE_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))
#define GNOME_PIE_IS_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_IS_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_ACTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))

typedef struct _GnomePieActionGroup GnomePieActionGroup;
typedef struct _GnomePieActionGroupClass GnomePieActionGroupClass;
typedef struct _GnomePieActionGroupPrivate GnomePieActionGroupPrivate;

#define GNOME_PIE_TYPE_ACTION (gnome_pie_action_get_type ())
#define GNOME_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION, GnomePieAction))
#define GNOME_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))
#define GNOME_PIE_IS_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_IS_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))

typedef struct _GnomePieAction GnomePieAction;
typedef struct _GnomePieActionClass GnomePieActionClass;
enum  {
	GNOME_PIE_ACTION_GROUP_0_PROPERTY,
	GNOME_PIE_ACTION_GROUP_ACTIONS_PROPERTY,
	GNOME_PIE_ACTION_GROUP_PARENT_ID_PROPERTY,
	GNOME_PIE_ACTION_GROUP_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_action_group_properties[GNOME_PIE_ACTION_GROUP_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION (gnome_pie_group_registry_typedescription_get_type ())
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescription))
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescriptionClass))
#define GNOME_PIE_GROUP_REGISTRY_IS_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_GROUP_REGISTRY_IS_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescriptionClass))

typedef struct _GnomePieGroupRegistryTypeDescription GnomePieGroupRegistryTypeDescription;
typedef struct _GnomePieGroupRegistryTypeDescriptionClass GnomePieGroupRegistryTypeDescriptionClass;
#define _gnome_pie_group_registry_typedescription_unref0(var) ((var == NULL) ? NULL : (var = (gnome_pie_group_registry_typedescription_unref (var), NULL)))

struct _GnomePieActionGroup {
	GObject parent_instance;
	GnomePieActionGroupPrivate * priv;
};

struct _GnomePieActionGroupClass {
	GObjectClass parent_class;
	void (*on_remove) (GnomePieActionGroup* self);
	void (*on_save) (GnomePieActionGroup* self, xmlTextWriter* writer);
	void (*on_load) (GnomePieActionGroup* self, xmlNode* data);
};

struct _GnomePieActionGroupPrivate {
	GeeArrayList* _actions;
	gchar* _parent_id;
};

static gint GnomePieActionGroup_private_offset;
static gpointer gnome_pie_action_group_parent_class = NULL;

VALA_EXTERN GType gnome_pie_action_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionGroup, g_object_unref)
VALA_EXTERN GType gnome_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAction, g_object_unref)
VALA_EXTERN void gnome_pie_action_group_on_remove (GnomePieActionGroup* self);
VALA_EXTERN void gnome_pie_action_group_on_save (GnomePieActionGroup* self,
                                     xmlTextWriter* writer);
VALA_EXTERN void gnome_pie_action_group_on_load (GnomePieActionGroup* self,
                                     xmlNode* data);
VALA_EXTERN GnomePieActionGroup* gnome_pie_action_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieActionGroup* gnome_pie_action_group_construct (GType object_type,
                                                       const gchar* parent_id);
static void gnome_pie_action_group_real_on_remove (GnomePieActionGroup* self);
static void gnome_pie_action_group_real_on_save (GnomePieActionGroup* self,
                                          xmlTextWriter* writer);
VALA_EXTERN gpointer gnome_pie_group_registry_typedescription_ref (gpointer instance);
VALA_EXTERN void gnome_pie_group_registry_typedescription_unref (gpointer instance);
VALA_EXTERN GParamSpec* gnome_pie_group_registry_param_spec_typedescription (const gchar* name,
                                                                 const gchar* nick,
                                                                 const gchar* blurb,
                                                                 GType object_type,
                                                                 GParamFlags flags);
VALA_EXTERN void gnome_pie_group_registry_value_set_typedescription (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN void gnome_pie_group_registry_value_take_typedescription (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN gpointer gnome_pie_group_registry_value_get_typedescription (const GValue* value);
VALA_EXTERN GType gnome_pie_group_registry_typedescription_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieGroupRegistryTypeDescription, gnome_pie_group_registry_typedescription_unref)
VALA_EXTERN GeeHashMap* gnome_pie_group_registry_get_descriptions (void);
VALA_EXTERN const gchar* gnome_pie_group_registry_typedescription_get_id (GnomePieGroupRegistryTypeDescription* self);
static void gnome_pie_action_group_real_on_load (GnomePieActionGroup* self,
                                          xmlNode* data);
VALA_EXTERN void gnome_pie_action_group_add_action (GnomePieActionGroup* self,
                                        GnomePieAction* new_action);
VALA_EXTERN GeeArrayList* gnome_pie_action_group_get_actions (GnomePieActionGroup* self);
VALA_EXTERN void gnome_pie_action_group_delete_all (GnomePieActionGroup* self);
VALA_EXTERN void gnome_pie_action_group_disable_quickactions (GnomePieActionGroup* self);
VALA_EXTERN void gnome_pie_action_set_is_quickaction (GnomePieAction* self,
                                          gboolean value);
VALA_EXTERN gboolean gnome_pie_action_group_has_quickaction (GnomePieActionGroup* self);
VALA_EXTERN gboolean gnome_pie_action_get_is_quickaction (GnomePieAction* self);
static void gnome_pie_action_group_set_actions (GnomePieActionGroup* self,
                                         GeeArrayList* value);
VALA_EXTERN const gchar* gnome_pie_action_group_get_parent_id (GnomePieActionGroup* self);
VALA_EXTERN void gnome_pie_action_group_set_parent_id (GnomePieActionGroup* self,
                                           const gchar* value);
static GObject * gnome_pie_action_group_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties);
static void gnome_pie_action_group_finalize (GObject * obj);
static GType gnome_pie_action_group_get_type_once (void);
static void _vala_gnome_pie_action_group_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);
static void _vala_gnome_pie_action_group_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec);

static inline gpointer
gnome_pie_action_group_get_instance_private (GnomePieActionGroup* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePieActionGroup_private_offset);
}

GnomePieActionGroup*
gnome_pie_action_group_construct (GType object_type,
                                  const gchar* parent_id)
{
	GnomePieActionGroup * self = NULL;
	g_return_val_if_fail (parent_id != NULL, NULL);
	self = (GnomePieActionGroup*) g_object_new (object_type, "parent-id", parent_id, NULL);
	return self;
}

GnomePieActionGroup*
gnome_pie_action_group_new (const gchar* parent_id)
{
	return gnome_pie_action_group_construct (GNOME_PIE_TYPE_ACTION_GROUP, parent_id);
}

static void
gnome_pie_action_group_real_on_remove (GnomePieActionGroup* self)
{
}

void
gnome_pie_action_group_on_remove (GnomePieActionGroup* self)
{
	GnomePieActionGroupClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GNOME_PIE_ACTION_GROUP_GET_CLASS (self);
	if (_klass_->on_remove) {
		_klass_->on_remove (self);
	}
}

static void
gnome_pie_action_group_real_on_save (GnomePieActionGroup* self,
                                     xmlTextWriter* writer)
{
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	const gchar* _tmp2_;
	gpointer _tmp3_;
	GnomePieGroupRegistryTypeDescription* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	g_return_if_fail (writer != NULL);
	_tmp0_ = gnome_pie_group_registry_get_descriptions ();
	_tmp1_ = _tmp0_;
	_tmp2_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) self));
	_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp1_, _tmp2_);
	_tmp4_ = (GnomePieGroupRegistryTypeDescription*) _tmp3_;
	_tmp5_ = gnome_pie_group_registry_typedescription_get_id (_tmp4_);
	_tmp6_ = _tmp5_;
	xmlTextWriterWriteAttribute (writer, (xmlChar*) "type", (xmlChar*) _tmp6_);
	_gnome_pie_group_registry_typedescription_unref0 (_tmp4_);
}

void
gnome_pie_action_group_on_save (GnomePieActionGroup* self,
                                xmlTextWriter* writer)
{
	GnomePieActionGroupClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GNOME_PIE_ACTION_GROUP_GET_CLASS (self);
	if (_klass_->on_save) {
		_klass_->on_save (self, writer);
	}
}

static void
gnome_pie_action_group_real_on_load (GnomePieActionGroup* self,
                                     xmlNode* data)
{
}

void
gnome_pie_action_group_on_load (GnomePieActionGroup* self,
                                xmlNode* data)
{
	GnomePieActionGroupClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GNOME_PIE_ACTION_GROUP_GET_CLASS (self);
	if (_klass_->on_load) {
		_klass_->on_load (self, data);
	}
}

void
gnome_pie_action_group_add_action (GnomePieActionGroup* self,
                                   GnomePieAction* new_action)
{
	GeeArrayList* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (new_action != NULL);
	_tmp0_ = self->priv->_actions;
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp0_, new_action);
}

void
gnome_pie_action_group_delete_all (GnomePieActionGroup* self)
{
	GeeArrayList* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_actions;
	gee_abstract_collection_clear ((GeeAbstractCollection*) _tmp0_);
}

void
gnome_pie_action_group_disable_quickactions (GnomePieActionGroup* self)
{
	g_return_if_fail (self != NULL);
	{
		GeeArrayList* _action_list = NULL;
		GeeArrayList* _tmp0_;
		gint _action_size = 0;
		GeeArrayList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _action_index = 0;
		_tmp0_ = self->priv->_actions;
		_action_list = _tmp0_;
		_tmp1_ = _action_list;
		_tmp2_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp1_);
		_tmp3_ = _tmp2_;
		_action_size = _tmp3_;
		_action_index = -1;
		while (TRUE) {
			gint _tmp4_;
			gint _tmp5_;
			GnomePieAction* action = NULL;
			GeeArrayList* _tmp6_;
			gpointer _tmp7_;
			GnomePieAction* _tmp8_;
			_action_index = _action_index + 1;
			_tmp4_ = _action_index;
			_tmp5_ = _action_size;
			if (!(_tmp4_ < _tmp5_)) {
				break;
			}
			_tmp6_ = _action_list;
			_tmp7_ = gee_abstract_list_get ((GeeAbstractList*) _tmp6_, _action_index);
			action = (GnomePieAction*) _tmp7_;
			_tmp8_ = action;
			gnome_pie_action_set_is_quickaction (_tmp8_, FALSE);
			_g_object_unref0 (action);
		}
	}
}

gboolean
gnome_pie_action_group_has_quickaction (GnomePieActionGroup* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	{
		GeeArrayList* _action_list = NULL;
		GeeArrayList* _tmp0_;
		gint _action_size = 0;
		GeeArrayList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _action_index = 0;
		_tmp0_ = self->priv->_actions;
		_action_list = _tmp0_;
		_tmp1_ = _action_list;
		_tmp2_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp1_);
		_tmp3_ = _tmp2_;
		_action_size = _tmp3_;
		_action_index = -1;
		while (TRUE) {
			gint _tmp4_;
			gint _tmp5_;
			GnomePieAction* action = NULL;
			GeeArrayList* _tmp6_;
			gpointer _tmp7_;
			GnomePieAction* _tmp8_;
			gboolean _tmp9_;
			gboolean _tmp10_;
			_action_index = _action_index + 1;
			_tmp4_ = _action_index;
			_tmp5_ = _action_size;
			if (!(_tmp4_ < _tmp5_)) {
				break;
			}
			_tmp6_ = _action_list;
			_tmp7_ = gee_abstract_list_get ((GeeAbstractList*) _tmp6_, _action_index);
			action = (GnomePieAction*) _tmp7_;
			_tmp8_ = action;
			_tmp9_ = gnome_pie_action_get_is_quickaction (_tmp8_);
			_tmp10_ = _tmp9_;
			if (_tmp10_) {
				result = TRUE;
				_g_object_unref0 (action);
				return result;
			}
			_g_object_unref0 (action);
		}
	}
	result = FALSE;
	return result;
}

GeeArrayList*
gnome_pie_action_group_get_actions (GnomePieActionGroup* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_actions;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
gnome_pie_action_group_set_actions (GnomePieActionGroup* self,
                                    GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_action_group_get_actions (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_actions);
		self->priv->_actions = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_action_group_properties[GNOME_PIE_ACTION_GROUP_ACTIONS_PROPERTY]);
	}
}

const gchar*
gnome_pie_action_group_get_parent_id (GnomePieActionGroup* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_parent_id;
	result = _tmp0_;
	return result;
}

void
gnome_pie_action_group_set_parent_id (GnomePieActionGroup* self,
                                      const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = gnome_pie_action_group_get_parent_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_parent_id);
		self->priv->_parent_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_action_group_properties[GNOME_PIE_ACTION_GROUP_PARENT_ID_PROPERTY]);
	}
}

static GObject *
gnome_pie_action_group_constructor (GType type,
                                    guint n_construct_properties,
                                    GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GnomePieActionGroup * self;
	GeeArrayList* _tmp0_;
	GeeArrayList* _tmp1_;
	parent_class = G_OBJECT_CLASS (gnome_pie_action_group_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup);
	_tmp0_ = gee_array_list_new (GNOME_PIE_TYPE_ACTION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
	_tmp1_ = _tmp0_;
	gnome_pie_action_group_set_actions (self, _tmp1_);
	_g_object_unref0 (_tmp1_);
	return obj;
}

static void
gnome_pie_action_group_class_init (GnomePieActionGroupClass * klass,
                                   gpointer klass_data)
{
	gnome_pie_action_group_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GnomePieActionGroup_private_offset);
	((GnomePieActionGroupClass *) klass)->on_remove = (void (*) (GnomePieActionGroup*)) gnome_pie_action_group_real_on_remove;
	((GnomePieActionGroupClass *) klass)->on_save = (void (*) (GnomePieActionGroup*, xmlTextWriter*)) gnome_pie_action_group_real_on_save;
	((GnomePieActionGroupClass *) klass)->on_load = (void (*) (GnomePieActionGroup*, xmlNode*)) gnome_pie_action_group_real_on_load;
	G_OBJECT_CLASS (klass)->get_property = _vala_gnome_pie_action_group_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gnome_pie_action_group_set_property;
	G_OBJECT_CLASS (klass)->constructor = gnome_pie_action_group_constructor;
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_action_group_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_ACTION_GROUP_ACTIONS_PROPERTY, gnome_pie_action_group_properties[GNOME_PIE_ACTION_GROUP_ACTIONS_PROPERTY] = g_param_spec_object ("actions", "actions", "actions", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_ACTION_GROUP_PARENT_ID_PROPERTY, gnome_pie_action_group_properties[GNOME_PIE_ACTION_GROUP_PARENT_ID_PROPERTY] = g_param_spec_string ("parent-id", "parent-id", "parent-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}

static void
gnome_pie_action_group_instance_init (GnomePieActionGroup * self,
                                      gpointer klass)
{
	self->priv = gnome_pie_action_group_get_instance_private (self);
}

static void
gnome_pie_action_group_finalize (GObject * obj)
{
	GnomePieActionGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup);
	_g_object_unref0 (self->priv->_actions);
	_g_free0 (self->priv->_parent_id);
	G_OBJECT_CLASS (gnome_pie_action_group_parent_class)->finalize (obj);
}

static GType
gnome_pie_action_group_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieActionGroupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_action_group_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieActionGroup), 0, (GInstanceInitFunc) gnome_pie_action_group_instance_init, NULL };
	GType gnome_pie_action_group_type_id;
	gnome_pie_action_group_type_id = g_type_register_static (G_TYPE_OBJECT, "GnomePieActionGroup", &g_define_type_info, 0);
	GnomePieActionGroup_private_offset = g_type_add_instance_private (gnome_pie_action_group_type_id, sizeof (GnomePieActionGroupPrivate));
	return gnome_pie_action_group_type_id;
}

GType
gnome_pie_action_group_get_type (void)
{
	static volatile gsize gnome_pie_action_group_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_action_group_type_id__once)) {
		GType gnome_pie_action_group_type_id;
		gnome_pie_action_group_type_id = gnome_pie_action_group_get_type_once ();
		g_once_init_leave (&gnome_pie_action_group_type_id__once, gnome_pie_action_group_type_id);
	}
	return gnome_pie_action_group_type_id__once;
}

static void
_vala_gnome_pie_action_group_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	GnomePieActionGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup);
	switch (property_id) {
		case GNOME_PIE_ACTION_GROUP_ACTIONS_PROPERTY:
		g_value_set_object (value, gnome_pie_action_group_get_actions (self));
		break;
		case GNOME_PIE_ACTION_GROUP_PARENT_ID_PROPERTY:
		g_value_set_string (value, gnome_pie_action_group_get_parent_id (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gnome_pie_action_group_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec)
{
	GnomePieActionGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup);
	switch (property_id) {
		case GNOME_PIE_ACTION_GROUP_ACTIONS_PROPERTY:
		gnome_pie_action_group_set_actions (self, g_value_get_object (value));
		break;
		case GNOME_PIE_ACTION_GROUP_PARENT_ID_PROPERTY:
		gnome_pie_action_group_set_parent_id (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

